<?php
// callback.php (Para Google Sign-In)

// Función para verificar HTTPS (Debe estar disponible)
function isSecure() {
    return
        (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off')
        || (!empty($_SERVER['SERVER_PORT']) && $_SERVER['SERVER_PORT'] == 443)
        || (!empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] === 'https')
        || (!empty($_SERVER['HTTP_X_FORWARDED_SSL']) && $_SERVER['HTTP_X_FORWARDED_SSL'] === 'on');
}

// Iniciar o continuar sesión CON la configuración de cookies correcta
if (session_status() == PHP_SESSION_NONE) {
    $cookieParams = session_get_cookie_params();
    session_set_cookie_params([
        'lifetime' => 0,
        'path' => '/',
        // 'domain' => '.venecloud.com', // Dominio NO necesario ahora
        'secure' => isSecure(),
        'httponly' => true,
        'samesite' => 'Lax'
    ]);
    session_start();
}

// Habilitar errores para depuración (quitar en producción)
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// --- Configuración DB (¡USA TUS CREDENCIALES REALES!) ---
$dbHost = 'localhost';
$dbName = 'dashvenecloud_venecloud_main_db';
$dbUser = 'dashvenecloud_root_db_venecloud';    // <<< ¡TU USUARIO REAL!
$dbPass = 'eJae}NiIwi)FAu#urr'; // <<< ¡TU CONTRASEÑA REAL!
$dbPort = 3306;

// --- Configuración de Google (¡TUS VALORES REALES!) ---
$googleClientId = '623157853988-lr1dm6ifmv2eev3f8bqfmd0a577tvog9.apps.googleusercontent.com';
$googleClientSecret = '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';
$googleRedirectUri = 'https://dashboard.venecloud.com/dashboard_app/api/v1/auth/callback.php'; // URL EXACTA registrada en Google Console

// --- URL de Login (para errores) ---
$loginUrlWithError = '/login.php?error='; // Dentro del mismo subdominio

// --- Función Helper para enviar respuestas JSON (NECESARIA SI HAY ERRORES ANTES DE REDIRIGIR) ---
function sendJsonResponse($statusCode, $data) {
     if (headers_sent()) {
        error_log("Headers already sent in callback.php, cannot send JSON response with status code {$statusCode}");
        // Evitar imprimir JSON si ya hay salida HTML (de error, por ejemplo)
        if (!ob_get_level() && error_reporting() !== 0) { // Solo si no hay buffer Y errores se muestran
            echo "<hr>Debug JSON (output prevented): " . htmlspecialchars(json_encode($data));
        }
        exit();
    }
    http_response_code($statusCode);
    header("Content-Type: application/json; charset=UTF-8");
    echo json_encode($data);
    exit();
}

// --- Procesar Callback ---
$code = $_GET['code'] ?? null;
$state_received = $_GET['state'] ?? null;
$state_expected = $_SESSION['oauth_state'] ?? null;

// Limpiar estado de la sesión inmediatamente
if (isset($_SESSION['oauth_state'])) {
    unset($_SESSION['oauth_state']);
}

// 1. Validar Estado CSRF
if (empty($state_received) || empty($state_expected) || $state_received !== $state_expected) {
    error_log("Error de estado OAuth en callback. Esperado: '{$state_expected}', Recibido: '{$state_received}'");
    header('Location: ' . $loginUrlWithError . 'google_state_mismatch');
    exit();
}

if (empty($code)) {
    error_log("Callback de Google sin código de autorización.");
    header('Location: ' . $loginUrlWithError . 'google_auth_failed');
    exit();
}

// --- Inicio Lógica Real OAuth ---
try {
    error_log("Callback: Código recibido: " . $code);

    // ==============================================================
    // PASO 2: Intercambiar Código por Tokens
    // ==============================================================
    $tokenEndpoint = 'https://oauth2.googleapis.com/token';
    $postData = [
        'code' => $code,
        'client_id' => $googleClientId,
        'client_secret' => $googleClientSecret,
        'redirect_uri' => $googleRedirectUri,
        'grant_type' => 'authorization_code'
    ];

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $tokenEndpoint);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postData));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/x-www-form-urlencoded']);
    curl_setopt($ch, CURLOPT_TIMEOUT, 15); // Añadir timeout
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true); // Verificar SSL
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);

    $response = curl_exec($ch);
    $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    $curlError = curl_error($ch);
    curl_close($ch);

    error_log("Callback: Respuesta cURL HTTP Code: " . $httpcode);
    if ($curlError) {
        error_log("Callback: Error cURL: " . $curlError);
        throw new Exception("Error de cURL al contactar Google: " . $curlError);
    }
    if ($httpcode >= 400) {
        error_log("Callback: Respuesta cURL Body (Error): " . $response);
        $errorData = json_decode($response, true);
        $errorMessage = $errorData['error_description'] ?? $response;
        throw new Exception("Google devolvió un error ({$httpcode}): " . $errorMessage);
    }
    error_log("Callback: Respuesta cURL Body (Éxito): " . $response);

    $tokens = json_decode($response, true);
    if (json_last_error() !== JSON_ERROR_NONE || !isset($tokens['id_token'])) {
         error_log("Callback: Error decodificando JSON de tokens o falta id_token: " . json_last_error_msg() . " | Respuesta: " . $response);
         throw new Exception("Error procesando respuesta de tokens de Google.");
    }
    $idToken = $tokens['id_token'];
    error_log("Callback: ID Token extraído (inicio): " . substr($idToken, 0, 20) . "...");


    // ==============================================================
    // PASO 3: Validar ID Token y extraer datos
    // ==============================================================
    // ¡¡¡IMPORTANTE!!! REEMPLAZAR ESTA SIMULACIÓN CON VALIDACIÓN JWT REAL
    // Se recomienda usar google/apiclient o una librería como firebase/php-jwt

    // --- SIMULACIÓN (INSEGURA - SOLO PARA DEPURACIÓN) ---
    error_log("Callback: Intentando decodificar ID Token (simulación - INSEGURO)...");
    $payloadParts = explode('.', $idToken);
    if (count($payloadParts) < 2) { throw new Exception("ID Token inválido (formato incorrecto)."); }
    $payloadEnc = $payloadParts[1];
    // Añadir padding si es necesario para base64_decode
    $payloadEnc .= str_repeat('=', strlen($payloadEnc) % 4);
    $payloadJson = base64_decode(str_replace(['-','_'], ['+','/'], $payloadEnc));
    if ($payloadJson === false) { throw new Exception("Fallo al decodificar Base64 del payload."); }
    $payload = json_decode($payloadJson, true);

    if (!$payload || !isset($payload['sub']) || !isset($payload['email'])) {
        error_log("Callback: Payload de ID Token inválido o faltan datos: " . $payloadJson);
        throw new Exception("Payload de ID Token inválido o faltan datos.");
    }
    // Verificar audiencia (aud) y emisor (iss) es CRUCIAL en una implementación real
    // if ($payload['aud'] !== $googleClientId) { throw new Exception("Audiencia inválida."); }
    // if ($payload['iss'] !== 'https://accounts.google.com' && $payload['iss'] !== 'accounts.google.com') { throw new Exception("Emisor inválido."); }
    // if (time() > $payload['exp']) { throw new Exception("Token expirado."); }

    $googleUserId = $payload['sub'];
    $userEmail = $payload['email'];
    $userName = $payload['name'] ?? 'Usuario Google';
    $avatarUrl = $payload['picture'] ?? null;
    $emailVerified = $payload['email_verified'] ?? false;
    error_log("Callback: Payload decodificado (¡SIN VALIDAR FIRMA!): sub={$googleUserId}, email={$userEmail}");
    // --- FIN SIMULACIÓN ---

     if (!$emailVerified) {
         error_log("Callback: Email de Google no verificado: " . $userEmail);
         throw new Exception("El correo electrónico de Google debe estar verificado.");
     }

    // ==============================================================
    // PASO 4: Buscar o Crear Usuario en tu DB (IMPLEMENTACIÓN REAL)
    // ==============================================================
    error_log("Callback: Intentando conectar a la DB...");
    $conn = new mysqli($dbHost, $dbUser, $dbPass, $dbName, (int)$dbPort);
    if ($conn->connect_error) {
        error_log("Error DB Connect (callback): " . $conn->connect_error);
        throw new Exception("Error interno del servidor (DB Connect callback).");
    }
    error_log("Callback: Conectado a DB. Buscando/Creando usuario...");

    $userIdToLogin = null;
    // Buscar prioritariamente por google_id
    $stmt_find = $conn->prepare("SELECT id FROM users WHERE google_id = ?");
    if ($stmt_find === false) { throw new Exception("DB Prepare Error (find by google_id): " . $conn->error); }
    $stmt_find->bind_param("s", $googleUserId);
    if (!$stmt_find->execute()) { throw new Exception("DB Execute Error (find by google_id): " . $stmt_find->error); }
    $stmt_find->bind_result($userIdToLogin);
    $foundByGoogleId = $stmt_find->fetch();
    $stmt_find->close();

    if ($foundByGoogleId === true) {
         error_log("Callback: Usuario encontrado por Google ID: {$userIdToLogin}");
         // Opcional: Actualizar nombre/avatar si cambiaron
         $stmt_update = $conn->prepare("UPDATE users SET name = ?, avatar_url = ?, updated_at = NOW() WHERE id = ?");
         if ($stmt_update) {
              $stmt_update->bind_param("ssi", $userName, $avatarUrl, $userIdToLogin);
              $stmt_update->execute();
              $stmt_update->close();
         } else { error_log("Error preparando update para usuario existente: " . $conn->error); }
    } else {
        // Si no, buscar por email
        $stmt_find_email = $conn->prepare("SELECT id FROM users WHERE email = ?");
        if ($stmt_find_email === false) { throw new Exception("DB Prepare Error (find by email): " . $conn->error); }
        $stmt_find_email->bind_param("s", $userEmail);
        if (!$stmt_find_email->execute()) { throw new Exception("DB Execute Error (find by email): " . $stmt_find_email->error); }
        $stmt_find_email->bind_result($userIdToLogin);
        $foundByEmail = $stmt_find_email->fetch();
        $stmt_find_email->close();

        if ($foundByEmail === true) {
             error_log("Callback: Usuario encontrado por Email: {$userIdToLogin}. Vinculando Google ID...");
             // Vincular cuenta existente
             $stmt_link = $conn->prepare("UPDATE users SET google_id = ?, name = ?, avatar_url = ?, updated_at = NOW() WHERE id = ?");
             if ($stmt_link) {
                 $stmt_link->bind_param("sssi", $googleUserId, $userName, $avatarUrl, $userIdToLogin);
                 $stmt_link->execute();
                 $stmt_link->close();
             } else { error_log("Error preparando link de Google ID: " . $conn->error); }
        } else {
            // Usuario realmente nuevo, crearlo
             error_log("Callback: Usuario no encontrado, creando nuevo registro con Google...");
            $stmt_insert = $conn->prepare("INSERT INTO users (name, email, google_id, avatar_url, email_verified_at, created_at, updated_at) VALUES (?, ?, ?, ?, NOW(), NOW(), NOW())");
            if ($stmt_insert === false) { throw new Exception("DB Prepare Error (insert google user): " . $conn->error); }
            // Asegurarse de que email_verified_at se establezca porque confiamos en Google
            $stmt_insert->bind_param("ssss", $userName, $userEmail, $googleUserId, $avatarUrl);
            if (!$stmt_insert->execute()) { throw new Exception("DB Execute Error (insert google user): " . $stmt_insert->error); }
            $userIdToLogin = $conn->insert_id;
            $stmt_insert->close();
             error_log("Callback: Nuevo usuario creado con Google (ID: {$userIdToLogin}).");
        }
    }
    $conn->close(); // Cerrar conexión DB

    // ==============================================================
    // PASO 5 y 6: Establecer Sesión y Redirigir
    // ==============================================================
    if ($userIdToLogin) {
        error_log("Callback: Estableciendo sesión para user_id: {$userIdToLogin}. Redirigiendo a /");
        session_regenerate_id(true);
        $_SESSION['user_id'] = $userIdToLogin;
        $_SESSION['user_email'] = $userEmail;
        $_SESSION['logged_in'] = true;
        $_SESSION['login_method'] = 'google';

        // --- ¡Redirigir al Dashboard AHORA! ---
        header('Location: /dashboard_app'); // Redirigir a la raíz del dashboard
        exit();

    } else {
        // Esto no debería ocurrir si la lógica DB es correcta
        throw new Exception("No se pudo obtener un ID de usuario válido después de buscar/crear.");
    }

} catch (Exception $e) {
    error_log("Error fatal en callback de Google: " . $e->getMessage());
    // Redirigir a login con mensaje de error genérico
    header('Location: ' . $loginUrlWithError . 'google_process_failed');
    exit();
}

?>