<?php
// login.php

// Función para verificar HTTPS (Debe estar disponible)
function isSecure() {
    return
        (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off')
        || (!empty($_SERVER['SERVER_PORT']) && $_SERVER['SERVER_PORT'] == 443)
        || (!empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] === 'https')
        || (!empty($_SERVER['HTTP_X_FORWARDED_SSL']) && $_SERVER['HTTP_X_FORWARDED_SSL'] === 'on');
}

// Iniciar o continuar sesión CON la configuración de cookies correcta
if (session_status() == PHP_SESSION_NONE) {
    $cookieParams = session_get_cookie_params();
    session_set_cookie_params([
        'lifetime' => 0, 'path' => '/', /*'domain' => '.venecloud.com',*/ 'secure' => isSecure(), 'httponly' => true, 'samesite' => 'Lax'
    ]);
    session_start();
}

// Habilitar errores para depuración (quitar en producción)
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// CORS Headers
header("Access-Control-Allow-Origin: *"); // Ajustar en producción
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Manejar preflight
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit();
}

// --- Configuración DB (¡USA TUS CREDENCIALES REALES!) ---
$dbHost = 'localhost';
$dbName = 'dashvenecloud_venecloud_main_db';
$dbUser = 'dashvenecloud_root_db_venecloud';    // <<< ¡TU USUARIO REAL!
$dbPass = 'eJae}NiIwi)FAu#urr'; // <<< ¡TU CONTRASEÑA REAL!
$dbPort = 3306;

// --- Función Helper para JSON ---
function sendJsonResponse($statusCode, $data) {
     if (headers_sent()) {
        error_log("Headers already sent in login.php, cannot send JSON response with status code {$statusCode}");
        if (!ob_get_level()) { echo json_encode($data); }
        exit();
    }
    http_response_code($statusCode);
    header("Content-Type: application/json; charset=UTF-8"); // Asegurar header
    echo json_encode($data);
    exit();
}

// --- Procesar solo POST ---
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    sendJsonResponse(405, ['error' => 'Método no permitido.']);
}

// --- 1. Recuperar Datos (DESDE FORMULARIO POST) ---
$email = trim($_POST['email'] ?? '');
$password = $_POST['password'] ?? ''; // No trim a password

// --- 2. Validar Entradas ---
if (empty($email) || empty($password)) {
    sendJsonResponse(400, ['error' => 'Email y contraseña son requeridos.']);
}

// --- 3. Buscar usuario ---
$conn = new mysqli($dbHost, $dbUser, $dbPass, $dbName, (int)$dbPort);
if ($conn->connect_error) {
    error_log("Error DB Connect (login.php): " . $conn->connect_error);
    sendJsonResponse(500, ['error' => 'Error interno del servidor (DB Connect).']);
}

$stmt = $conn->prepare("SELECT id, password_hash FROM users WHERE email = ?");
if ($stmt === false) {
    error_log("Error DB Prepare (login): " . $conn->error);
    sendJsonResponse(500, ['error' => 'Error interno del servidor (DB Prepare login).']);
}
$stmt->bind_param("s", $email);
if (!$stmt->execute()) {
    error_log("Error DB Execute (login): " . $stmt->error);
    sendJsonResponse(500, ['error' => 'Error interno del servidor (DB Execute login).']);
}

// Usar bind_result y fetch
$user_id = null;
$password_hash_from_db = null;
$stmt->bind_result($user_id, $password_hash_from_db);
$user_found = $stmt->fetch();
$stmt->close();
$conn->close();

// --- 4. Verificar contraseña ---
if ($user_found && isset($password_hash_from_db) && password_verify($password, $password_hash_from_db)) {
    // ¡Contraseña correcta!

    // 5. Establecer la sesión
    session_regenerate_id(true);
    $_SESSION['user_id'] = $user_id;
    $_SESSION['user_email'] = $email;
    $_SESSION['logged_in'] = true;

    // 6. Devolver JSON de éxito (el JS del frontend redirige)
    sendJsonResponse(200, ['success' => true, 'message' => 'Login exitoso.']); // <<< CORRECTO

} else {
    // Usuario no encontrado o contraseña incorrecta
    sendJsonResponse(401, ['error' => 'Credenciales inválidas.']);
}

?>