<?php
// register.php

// Función para verificar HTTPS (Debe estar disponible)
function isSecure() {
    return
        (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off')
        || (!empty($_SERVER['SERVER_PORT']) && $_SERVER['SERVER_PORT'] == 443)
        || (!empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] === 'https')
        || (!empty($_SERVER['HTTP_X_FORWARDED_SSL']) && $_SERVER['HTTP_X_FORWARDED_SSL'] === 'on');
}

// Iniciar o continuar sesión CON la configuración de cookies correcta
if (session_status() == PHP_SESSION_NONE) {
     $cookieParams = session_get_cookie_params();
    session_set_cookie_params([
        'lifetime' => 0, 'path' => '/', /*'domain' => '.venecloud.com',*/ 'secure' => isSecure(), 'httponly' => true, 'samesite' => 'Lax'
    ]);
    session_start();
}

// Habilitar errores para depuración
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// CORS Headers
header("Access-Control-Allow-Origin: *"); // Ajustar en producción
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Manejar preflight
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit();
}

// --- Configuración DB (¡USA TUS CREDENCIALES REALES!) ---
$dbHost = 'localhost';
$dbName = 'dashvenecloud_venecloud_main_db';
$dbUser = 'dashvenecloud_root_db_venecloud';    // <<< ¡TU USUARIO REAL!
$dbPass = 'eJae}NiIwi)FAu#urr'; // <<< ¡TU CONTRASEÑA REAL!
$dbPort = 3306;

// --- Función Helper para JSON ---
function sendJsonResponse($statusCode, $data) {
     if (headers_sent()) {
        error_log("Headers already sent in register.php, cannot send JSON response with status code {$statusCode}");
        if (!ob_get_level()) { echo json_encode($data); }
        exit();
    }
    http_response_code($statusCode);
    header("Content-Type: application/json; charset=UTF-8");
    echo json_encode($data);
    exit();
}

// --- Procesar solo POST ---
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    sendJsonResponse(405, ['error' => 'Método no permitido.']);
}

// --- 1. Recuperar Datos del $_POST ---
$name = trim($_POST['name'] ?? '');
$email = trim($_POST['email'] ?? '');
$password = $_POST['password'] ?? '';
$passwordConfirm = $_POST['password_confirmation'] ?? '';

// --- 2. Validar Entradas ---
if (empty($name)) { sendJsonResponse(400, ['error' => 'El nombre completo es requerido.']); }
if (empty($email) || !filter_var($email, FILTER_VALIDATE_EMAIL)) { sendJsonResponse(400, ['error' => 'El correo electrónico no es válido.']); }
if (empty($password)) { sendJsonResponse(400, ['error' => 'La contraseña es requerida.']); }
if (strlen($password) < 8) { sendJsonResponse(400, ['error' => 'La contraseña debe tener al menos 8 caracteres.']); }
if ($password !== $passwordConfirm) { sendJsonResponse(400, ['error' => 'Las contraseñas no coinciden.']); }

// --- 3. Verificar si el email ya existe ---
$conn = new mysqli($dbHost, $dbUser, $dbPass, $dbName, (int)$dbPort);
if ($conn->connect_error) {
    error_log("Error DB Connect (register.php): " . $conn->connect_error);
    sendJsonResponse(500, ['error' => 'Error interno del servidor (DB Connect).']);
}

$stmt_check = $conn->prepare("SELECT id FROM users WHERE email = ?");
if ($stmt_check === false) { /* ... manejo error ... */ sendJsonResponse(500, ['error' => 'DB Error']); }
$stmt_check->bind_param("s", $email);
if (!$stmt_check->execute()) { /* ... manejo error ... */ sendJsonResponse(500, ['error' => 'DB Error']); }
$stmt_check->store_result();
if ($stmt_check->num_rows > 0) {
    $stmt_check->close();
    $conn->close();
    sendJsonResponse(409, ['error' => 'El correo electrónico ya está registrado.']);
}
$stmt_check->close();

// --- 4. Hashear la contraseña ---
$passwordHash = password_hash($password, PASSWORD_DEFAULT);
if ($passwordHash === false) { /* ... manejo error ... */ sendJsonResponse(500, ['error' => 'Hashing Error']); }

// --- 5. Insertar nuevo usuario ---
$stmt_insert = $conn->prepare("INSERT INTO users (name, email, password_hash, created_at, updated_at) VALUES (?, ?, ?, NOW(), NOW())");
if ($stmt_insert === false) { /* ... manejo error ... */ sendJsonResponse(500, ['error' => 'DB Error']); }
$stmt_insert->bind_param("sss", $name, $email, $passwordHash);

if ($stmt_insert->execute()) {
    $newUserId = $conn->insert_id;
    $stmt_insert->close();
    $conn->close();

    // --- 6. Establecer la sesión ---
    session_regenerate_id(true);
    $_SESSION['user_id'] = $newUserId;
    $_SESSION['user_email'] = $email;
    $_SESSION['logged_in'] = true;

    // --- 7. REDIRIGIR AL DASHBOARD ---
    // Como el formulario HTML envía directamente aquí, la redirección PHP es apropiada.
    header('Location: https://dashboard.venecloud.com/dashboard_app/'); // <<< Redirigir a la raíz del dashboard
    exit(); // ¡CRUCIAL salir después de header()!

} else {
    $error_msg = $stmt_insert->error;
    $stmt_insert->close();
    $conn->close();
    error_log("Error DB Execute (insert): " . $error_msg . " for email: " . $email);
    sendJsonResponse(500, ['error' => 'Error al registrar el usuario.', 'details' => $error_msg]);
}

?>