<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
// --- Configuración ---
// Permitir CORS (Cross-Origin Resource Sharing) - ¡IMPORTANTE PARA DESARROLLO LOCAL!
// En producción, sé más específico con el origen permitido.
header("Access-Control-Allow-Origin: *"); // Permitir cualquier origen (para desarrollo)
// header("Access-Control-Allow-Origin: http://localhost:TU_PUERTO_FRONTEND"); // Ejemplo más específico
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST, OPTIONS"); // Permitir POST y OPTIONS (para preflight)
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Manejar petición OPTIONS (preflight request para CORS)
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit();
}

// --- Configuración de Conexión a MySQL (desde Laragon) ---
// Idealmente, estas credenciales estarían en un archivo de configuración separado y no en el script.
$dbHost = getenv('DB_HOST') ?: 'suta-t.vps.co.ve';
$dbUser = getenv('DB_USER') ?: 'superusuario';
$dbPass = getenv('DB_PASSWORD') ?: '$Chenier2025$'; // Tu contraseña de Laragon si la tienes
$dbPort = getenv('DB_PORT') ?: 3306;

// --- Funciones Helper ---
function generateSecurePassword($length = 16) {
    $charset = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*()_+~`|}{[]:;?><,./-=';
    $password = '';
    $n = strlen($charset);
    for ($i = 0; $i < $length; $i++) {
        $password .= $charset[random_int(0, $n - 1)];
    }
    return $password;
}

function sendJsonResponse($statusCode, $data) {
    http_response_code($statusCode);
    echo json_encode($data);
    exit();
}

// --- Lógica del Endpoint ---
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Obtener datos del cuerpo de la petición JSON
    $inputJSON = file_get_contents('php://input');
    $input = json_decode($inputJSON, TRUE); // Convertir a array asociativo

    $dbName = isset($input['dbName']) ? trim($input['dbName']) : null;
    $sqlScript = isset($input['sqlScript']) ? trim($input['sqlScript']) : '';

    // Validación básica
    if (empty($dbName) || !preg_match('/^[a-z0-9_]+$/i', $dbName)) {
        sendJsonResponse(400, ['error' => 'Nombre de base de datos inválido. Solo letras, números y guiones bajos.']);
    }
    // Podríamos permitir script vacío
    // if (empty($sqlScript)) {
    //     sendJsonResponse(400, ['error' => 'Script SQL es requerido.']);
    // }

    // Generar credenciales
    $userPrefix = 'vcld_user'; // Ejemplo, podría venir de la sesión del usuario autenticado
    $finalDbName = $userPrefix . '_' . $dbName;
    $dbUserName = $userPrefix . '_' . substr($dbName, 0, min(strlen($dbName), 10)) . '_usr';
    $dbPassword = generateSecurePassword();

    $conn = null; // Variable para la conexión

    try {
        // 1. Conectarse al servidor MySQL (usando mysqli)
        $conn = new mysqli($dbHost, $dbUser, $dbPass, null, (int)$dbPort);
        if ($conn->connect_error) {
            throw new Exception("Error de conexión al servidor MySQL: " . $conn->connect_error);
        }
        error_log("Conectado al servidor MySQL.");

        // 2. Crear la nueva base de datos
        $sqlCreateDb = "CREATE DATABASE IF NOT EXISTS `{$finalDbName}` CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;";
        if (!$conn->query($sqlCreateDb)) {
            throw new Exception("Error al crear la base de datos '{$finalDbName}': " . $conn->error);
        }
        error_log("Base de datos '{$finalDbName}' creada o ya existente.");

        // 3. Crear un nuevo usuario para esta base de datos
        // NOTA: Manejo de errores para creación de usuario en MySQL 8+ puede ser necesario
        $sqlCreateUser = "CREATE USER IF NOT EXISTS '{$dbUserName}'@'%' IDENTIFIED BY '{$dbPassword}';";
        if (!$conn->query($sqlCreateUser)) {
            // Intentar con mysql_native_password para MySQL 8+ si falla
            $sqlCreateUserNative = "CREATE USER IF NOT EXISTS '{$dbUserName}'@'%' IDENTIFIED WITH mysql_native_password BY '{$dbPassword}';";
            error_log("Fallo al crear usuario {$dbUserName}, reintentando con mysql_native_password...");
            if (!$conn->query($sqlCreateUserNative)) {
                 throw new Exception("Error al crear el usuario '{$dbUserName}': " . $conn->error);
            }
             error_log("Usuario '{$dbUserName}' creado con mysql_native_password.");
        } else {
             error_log("Usuario '{$dbUserName}' creado.");
        }


        // 4. Otorgar privilegios
        $sqlGrant = "GRANT ALL PRIVILEGES ON `{$finalDbName}`.* TO '{$dbUserName}'@'%';";
        if (!$conn->query($sqlGrant)) {
            throw new Exception("Error al otorgar privilegios a '{$dbUserName}': " . $conn->error);
        }
        error_log("Privilegios otorgados a '{$dbUserName}' sobre '{$finalDbName}'.");

        if (!$conn->query("FLUSH PRIVILEGES;")) {
            error_log("Advertencia: FLUSH PRIVILEGES falló. Puede no ser necesario en todas las configuraciones.");
        }

        // 5. Seleccionar la nueva base de datos y ejecutar el script SQL
        if (!empty($sqlScript)) {
            if (!$conn->select_db($finalDbName)) {
                throw new Exception("Error al seleccionar la base de datos '{$finalDbName}': " . $conn->error);
            }
            error_log("Cambiado a base de datos '{$finalDbName}'. Ejecutando script...");

            // mysqli::multi_query para ejecutar múltiples sentencias
            // ¡CUIDADO! Asegúrate de que el script SQL sea seguro.
            if ($conn->multi_query($sqlScript)) {
                do {
                    // store_result() o use_result() son necesarios entre sentencias
                    if ($result = $conn->store_result()) {
                        $result->free();
                    }
                } while ($conn->more_results() && $conn->next_result());
                 error_log("Script SQL procesado.");
            } else {
                // Si multi_query falla, capturar el error de la primera sentencia fallida
                error_log("Error al ejecutar el script SQL en '{$finalDbName}': " . $conn->error);
                // Podrías decidir si esto es un error fatal o no
            }
             // Revisar errores después de multi_query (si alguna sentencia falló)
            if ($conn->error) {
                error_log("Error persistente después de multi_query en '{$finalDbName}': " . $conn->error);
                 // Podrías lanzar una excepción aquí si consideras cualquier error en el script como fatal
                 // throw new Exception("Error durante la ejecución del script SQL: " . $conn->error);
            }
        }

        // Si todo fue bien, devolver las credenciales
        sendJsonResponse(201, [
            'message' => "Base de datos '{$finalDbName}' creada y script ejecutado.",
            'credentials' => [
                'host' => $dbHost, // O el host público
                'port' => (int)$dbPort,
                'user' => $dbUserName,
                'password' => $dbPassword, // ¡SOLO devolver en la creación!
                'database' => $finalDbName,
            ]
        ]);

    } catch (Exception $e) {
        error_log("Error API: " . $e->getMessage());
        // Intentar limpiar si algo falló (opcional, manejo de errores complejo)
        // if ($conn) {
        //     $conn->query("DROP USER IF EXISTS '{$dbUserName}'@'%'");
        //     $conn->query("DROP DATABASE IF EXISTS `{$finalDbName}`");
        // }
        sendJsonResponse(500, ['error' => 'Error interno del servidor al crear la base de datos.', 'details' => $e->getMessage()]);
    } finally {
        if ($conn) {
            $conn->close();
            error_log('Conexión MySQL cerrada.');
        }
    }
} else {
    sendJsonResponse(405, ['error' => 'Método no permitido. Solo se acepta POST.']);
}
?>