<?php
// api/v1/databases.php

// Habilitar errores para depuración (quitar en producción)
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// --- INCLUIR auth_check.php PARA OBTENER EL ID DEL USUARIO LOGUEADO ---
// ¡¡¡AJUSTA ESTA RUTA SI ES NECESARIO!!!
// Si auth_check.php está en /api/v1/auth/ y este script está en /api/v1/
require_once __DIR__ . '/auth/auth_check.php'; // Asume que auth_check está en una subcarpeta 'auth'

// $currentUserId y $currentUserEmail deberían estar definidos por auth_check.php
// y la sesión ya debería estar iniciada con los parámetros correctos.

if (!isset($currentUserId) || !$currentUserId) { // Verificar que $currentUserId se estableció
    // El header Content-Type ya se habrá enviado por auth_check si hay error y llama a sendJsonResponse
    // Así que aquí podríamos solo asegurar que se envíe una respuesta JSON si no lo hizo auth_check
    // Pero auth_check ya debería haber hecho exit() si no hay sesión.
    // Este es un chequeo extra.
    http_response_code(401);
    echo json_encode(['error' => 'Usuario no autenticado o ID de usuario no encontrado en sesión.']);
    exit();
}
// --- FIN INCLUSIÓN ---


// --- Configuración ---
// CORS Headers
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Manejar petición OPTIONS
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit();
}

// --- Configuración de Conexión a MySQL (SUPERUSUARIO de tu VPS) ---
$dbHost = getenv('DB_HOST') ?: 'suta-t.vps.co.ve';
$dbMasterUser = getenv('DB_USER') ?: 'superusuario'; // Usuario con permisos para crear DBs y Usuarios
$dbMasterPass = getenv('DB_PASSWORD') ?: '$Chenier2025$';
$dbPort = getenv('DB_PORT') ?: 3306;

// Nombre de la base de datos principal de VeneCloud (donde está la tabla 'users' y 'user_databases')
$venecloudMainDbName = 'dashvenecloud_venecloud_main_db'; // <<< ¡TU NOMBRE DE DB PRINCIPAL!

// --- Funciones Helper ---
function generateSecurePassword($length = 16) {
    $charset = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*()_+~`|}{[]:;?><,./-=';
    $password = ''; $n = strlen($charset);
    for ($i = 0; $i < $length; $i++) { $password .= $charset[random_int(0, $n - 1)]; }
    return $password;
}

function sendJsonResponse($statusCode, $data) { // Asegurar que esté definida si auth_check no la define
    if (headers_sent()) {
        error_log("Headers already sent (databases.php), cannot send JSON. Status: {$statusCode}");
        if (!ob_get_level()) { echo json_encode($data); }
        exit();
    }
    http_response_code($statusCode);
    header("Content-Type: application/json; charset=UTF-8");
    echo json_encode($data);
    exit();
}

// --- Lógica del Endpoint ---
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $inputJSON = file_get_contents('php://input');
    $input = json_decode($inputJSON, TRUE);

    $dbNameFromUser = isset($input['dbName']) ? trim($input['dbName']) : null;
    $sqlScript = isset($input['sqlScript']) ? trim($input['sqlScript']) : '';

    if (empty($dbNameFromUser) || !preg_match('/^[a-z0-9_]+$/i', $dbNameFromUser)) {
        sendJsonResponse(400, ['error' => 'Nombre de base de datos inválido. Solo letras, números y guiones bajos.']);
    }

    // Generar nombres y contraseña para la nueva DB y su usuario
    // Podrías usar parte del email o ID del usuario de VeneCloud para el prefijo si quieres
    $dbUserPrefix = 'vcld_u' . $currentUserId . '_'; // Prefijo con ID de usuario de VeneCloud
    $finalDbName = $dbUserPrefix . $dbNameFromUser;
    // Limitar longitud de nombres de usuario MySQL (MySQL tiene límites)
    $baseDbUserName = substr($dbNameFromUser, 0, max(1, 16 - strlen($dbUserPrefix) - 4)) . '_usr'; // ej: _usr para 4 chars
    $dbUserNameForNewDb = $dbUserPrefix . $baseDbUserName;
    // Asegurar que el nombre de usuario no exceda el límite de MySQL (generalmente 32 o similar)
    $dbUserNameForNewDb = substr($dbUserNameForNewDb, 0, 32);

    $dbPasswordForNewDb = generateSecurePassword();

    $connAdmin = null; // Conexión como superusuario

    try {
        // 1. Conectarse al servidor MySQL con el usuario administrador de la plataforma
        $connAdmin = new mysqli($dbHost, $dbMasterUser, $dbMasterPass, null, (int)$dbPort);
        if ($connAdmin->connect_error) {
            throw new Exception("Error de conexión (admin) al servidor MySQL: " . $connAdmin->connect_error);
        }
        error_log("DB_CREATE: Admin conectado al servidor MySQL.");

        // 2. Crear la nueva base de datos para el cliente
        $sqlCreateDb = "CREATE DATABASE IF NOT EXISTS `{$finalDbName}` CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;";
        if (!$connAdmin->query($sqlCreateDb)) {
            throw new Exception("Error al crear la base de datos '{$finalDbName}': " . $connAdmin->error);
        }
        error_log("DB_CREATE: Base de datos '{$finalDbName}' creada o ya existente.");

        // 3. Crear un nuevo usuario MySQL para esta base de datos
        $sqlCreateUser = "CREATE USER IF NOT EXISTS '{$dbUserNameForNewDb}'@'%' IDENTIFIED BY '{$dbPasswordForNewDb}';";
        if (!$connAdmin->query($sqlCreateUser)) {
            $sqlCreateUserNative = "CREATE USER IF NOT EXISTS '{$dbUserNameForNewDb}'@'%' IDENTIFIED WITH mysql_native_password BY '{$dbPasswordForNewDb}';";
            error_log("DB_CREATE: Fallo al crear usuario {$dbUserNameForNewDb}, reintentando con mysql_native_password...");
            if (!$connAdmin->query($sqlCreateUserNative)) {
                 throw new Exception("Error al crear el usuario '{$dbUserNameForNewDb}': " . $connAdmin->error);
            }
             error_log("DB_CREATE: Usuario '{$dbUserNameForNewDb}' creado con mysql_native_password.");
        } else {
             error_log("DB_CREATE: Usuario '{$dbUserNameForNewDb}' creado.");
        }

        // 4. Otorgar privilegios al nuevo usuario sobre SU base de datos
        $sqlGrant = "GRANT ALL PRIVILEGES ON `{$finalDbName}`.* TO '{$dbUserNameForNewDb}'@'%';";
        if (!$connAdmin->query($sqlGrant)) {
            throw new Exception("Error al otorgar privilegios a '{$dbUserNameForNewDb}' sobre '{$finalDbName}': " . $connAdmin->error);
        }
        error_log("DB_CREATE: Privilegios otorgados a '{$dbUserNameForNewDb}' sobre '{$finalDbName}'.");

        if (!$connAdmin->query("FLUSH PRIVILEGES;")) {
            error_log("DB_CREATE: Advertencia: FLUSH PRIVILEGES falló.");
        }

        // 5. Ejecutar el script SQL del usuario DENTRO de la nueva base de datos
        if (!empty($sqlScript)) {
            if (!$connAdmin->select_db($finalDbName)) { // Cambiar al contexto de la nueva DB
                throw new Exception("Error al seleccionar la base de datos '{$finalDbName}' para ejecutar script: " . $connAdmin->error);
            }
            error_log("DB_CREATE: Cambiado a base de datos '{$finalDbName}'. Ejecutando script...");
            if ($connAdmin->multi_query($sqlScript)) {
                do { if ($result = $connAdmin->store_result()) { $result->free(); } }
                while ($connAdmin->more_results() && $connAdmin->next_result());
                error_log("DB_CREATE: Script SQL procesado.");
            } else {
                error_log("DB_CREATE: Error al ejecutar multi_query en '{$finalDbName}': " . $connAdmin->error);
            }
            if ($connAdmin->error) { // Chequear errores después de multi_query
                error_log("DB_CREATE: Error persistente después de multi_query en '{$finalDbName}': " . $connAdmin->error);
                // Podrías lanzar excepción si un error en el script del usuario debe detener todo
            }
        }

        // --- Guardar información en la tabla user_databases DE TU DB PRINCIPAL ---
        // Es crucial que $connAdmin ahora se conecte o seleccione tu DB principal
        if (!$connAdmin->select_db($venecloudMainDbName)) {
            throw new Exception("Error al seleccionar la base de datos principal de VeneCloud ('{$venecloudMainDbName}') para registrar la DB del usuario: " . $connAdmin->error);
        }
        error_log("DB_CREATE: Seleccionada DB principal '{$venecloudMainDbName}' para loguear.");

        $stmt_log_db = $connAdmin->prepare(
            "INSERT INTO user_databases (user_id, db_name_on_server, db_username_on_server, db_host, db_port, created_at) VALUES (?, ?, ?, ?, ?, NOW())"
        );
        if ($stmt_log_db === false) {
            error_log("DB_CREATE: Error preparando statement para loguear DB: " . $connAdmin->error);
            // No lanzar excepción aquí, es un log interno, pero es importante saber si falla
        } else {
            $dbHostForClient = getenv('DB_HOST') ?: 'suta-t.vps.co.ve'; // El host que el cliente usará
            $dbPortForClient = (int)(getenv('DB_PORT') ?: 3306);

            $stmt_log_db->bind_param("isssi", $currentUserId, $finalDbName, $dbUserNameForNewDb, $dbHostForClient, $dbPortForClient);
            if (!$stmt_log_db->execute()) {
                error_log("DB_CREATE: Error ejecutando statement para loguear DB: " . $stmt_log_db->error);
            } else {
                error_log("DB_CREATE: Base de datos '{$finalDbName}' registrada para usuario ID {$currentUserId}.");
            }
            $stmt_log_db->close();
        }
        // --- FIN Guardar ---

        // Devolver credenciales para el cliente
        sendJsonResponse(201, [
            'message' => "Base de datos '{$finalDbName}' creada y script ejecutado.",
            'credentials' => [
                'host' => $dbHostForClient,
                'port' => $dbPortForClient,
                'user' => $dbUserNameForNewDb,
                'password' => $dbPasswordForNewDb, // SOLO MOSTRAR EN CREACIÓN
                'database' => $finalDbName,
            ]
        ]);

    } catch (Exception $e) {
        error_log("DB_CREATE API Error: " . $e->getMessage());
        sendJsonResponse(500, ['error' => 'Error interno del servidor al crear la base de datos.', 'details' => $e->getMessage()]);
    } finally {
        if ($connAdmin) {
            $connAdmin->close();
            error_log('DB_CREATE: Conexión MySQL (admin) cerrada.');
        }
    }
} else {
    sendJsonResponse(405, ['error' => 'Método no permitido. Solo se acepta POST.']);
}
?>