<?php
// api/v1/projects.php

// Habilitar errores para depuración
ini_set('display_errors', 1); ini_set('display_startup_errors', 1); error_reporting(E_ALL);

// Incluir auth_check para obtener $currentUserId
// Asegúrate que la ruta a auth_check.php sea correcta desde este script
// Si projects.php está en /api/v1/ y auth_check.php está en /api/v1/auth/
require_once __DIR__ . '/auth/auth_check.php';

if (!isset($currentUserId) || !$currentUserId) {
    // auth_check.php ya debería haber hecho exit() si no hay sesión
    // Este es un chequeo de seguridad adicional
    http_response_code(401);
    echo json_encode(['error' => 'Usuario no autenticado o ID de usuario no disponible.']);
    exit();
}

// CORS Headers y manejo OPTIONS
header("Access-Control-Allow-Origin: *"); // Ajustar en producción
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST, GET, OPTIONS");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit();
}

// --- Configuración DB ---
$dbHost = 'localhost';
$dbName = 'dashvenecloud_venecloud_main_db'; // Base de datos donde están 'users', 'projects', etc.
$dbUser = 'dashvenecloud_root_db_venecloud'; // Usuario con permisos para LEER estas tablas
$dbPass = 'eJae}NiIwi)FAu#urr';
$dbPort = 3306;

// --- Función Helper (Asegúrate que esté definida si no está en auth_check.php o inclúyela aquí) ---
if (!function_exists('sendJsonResponse')) {
    function sendJsonResponse($statusCode, $data) {
        if (headers_sent($file, $line)) {
            error_log("Headers already sent in projects.php (output started at {$file}:{$line}), cannot send JSON. Status: {$statusCode}");
            if (!ob_get_level() && error_reporting() !== 0) { echo "<hr>Debug JSON (output prevented): " . htmlspecialchars(json_encode($data));}
            exit();
        }
        http_response_code($statusCode);
        header("Content-Type: application/json; charset=UTF-8");
        echo json_encode($data);
        exit();
    }
}


// --- Lógica del Endpoint ---

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    $conn = new mysqli($dbHost, $dbUser, $dbPass, $dbName, (int)$dbPort);
    if ($conn->connect_error) {
        error_log("DB Connect Error (GET projects): " . $conn->connect_error);
        sendJsonResponse(500, ['error' => 'Error interno del servidor (DB Connect).']);
    }

    $projectSlug = trim($_GET['slug'] ?? '');

    if (!empty($projectSlug)) {
        // --- OBTENER DETALLES DE UN PROYECTO ESPECÍFICO Y SUS RECURSOS ---
        $stmt_project = $conn->prepare("SELECT id, name, slug, description, created_at FROM projects WHERE user_id = ? AND slug = ?");
        if ($stmt_project === false) { sendJsonResponse(500, ['error' => 'Error interno (DB Prepare Project Details).']); }
        $stmt_project->bind_param("is", $currentUserId, $projectSlug);
        if (!$stmt_project->execute()) { sendJsonResponse(500, ['error' => 'Error interno (DB Execute Project Details).']); }

        $result_project = $stmt_project->get_result(); // Asumiendo mysqlnd
        $project = $result_project->fetch_assoc();
        $stmt_project->close();

        if ($project) {
            $projectId = (int)$project['id']; // Asegurar que es entero
            $project['applications_frontend'] = [];
            $project['applications_api'] = [];
            $project['databases'] = [];

            // Obtener aplicaciones frontend
            $stmt_apps_fe = $conn->prepare("SELECT id, name, url, status, type, created_at FROM applications WHERE project_id = ? AND user_id = ? AND type = 'frontend' ORDER BY name ASC");
            if ($stmt_apps_fe) {
                $stmt_apps_fe->bind_param("ii", $projectId, $currentUserId); // project_id, user_id
                $stmt_apps_fe->execute();
                $result_apps_fe = $stmt_apps_fe->get_result();
                while ($row = $result_apps_fe->fetch_assoc()) {
                    $project['applications_frontend'][] = $row;
                }
                $stmt_apps_fe->close();
            } else { error_log("Error preparando statement para apps frontend: " . $conn->error); }

            // Obtener aplicaciones API
            $stmt_apps_api = $conn->prepare("SELECT id, name, url, status, type, created_at FROM applications WHERE project_id = ? AND user_id = ? AND type = 'api' ORDER BY name ASC");
            if ($stmt_apps_api) {
                $stmt_apps_api->bind_param("ii", $projectId, $currentUserId);
                $stmt_apps_api->execute();
                $result_apps_api = $stmt_apps_api->get_result();
                while ($row = $result_apps_api->fetch_assoc()) {
                    $project['applications_api'][] = $row;
                }
                $stmt_apps_api->close();
            } else { error_log("Error preparando statement para apps api: " . $conn->error); }

            // Obtener bases de datos
            // Asegúrate que las columnas coincidan con tu tabla `user_databases`
            $stmt_dbs = $conn->prepare("SELECT id, db_name_on_server, db_username_on_server, db_host, status, created_at FROM user_databases WHERE project_id = ? AND user_id = ? ORDER BY db_name_on_server ASC");
            if ($stmt_dbs) {
                $stmt_dbs->bind_param("ii", $projectId, $currentUserId);
                $stmt_dbs->execute();
                $result_dbs = $stmt_dbs->get_result();
                while ($row = $result_dbs->fetch_assoc()) {
                    $project['databases'][] = $row;
                }
                $stmt_dbs->close();
            } else { error_log("Error preparando statement para databases: " . $conn->error); }

            sendJsonResponse(200, ['success' => true, 'project' => $project]);
        } else {
            sendJsonResponse(404, ['success' => false, 'error' => 'Proyecto no encontrado o no tienes acceso.']);
        }

    } else {
        // --- LISTAR TODOS LOS PROYECTOS DEL USUARIO ---
        $stmt_list = $conn->prepare("SELECT id, name, slug, description, created_at FROM projects WHERE user_id = ? ORDER BY created_at DESC");
        if ($stmt_list === false) { sendJsonResponse(500, ['error' => 'Error interno (DB Prepare List).']); }
        $stmt_list->bind_param("i", $currentUserId);
        if (!$stmt_list->execute()) { sendJsonResponse(500, ['error' => 'Error interno (DB Execute List).']); }

        $result_list = $stmt_list->get_result();
        $projects = [];
        while ($row = $result_list->fetch_assoc()) {
            $projects[] = $row;
        }
        $stmt_list->close();
        sendJsonResponse(200, ['success' => true, 'projects' => $projects]);
    }
    $conn->close();

} elseif ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // --- CREAR PROYECTO ---
    $inputJSON = file_get_contents('php://input');
    $input = json_decode($inputJSON, TRUE);

    $projectName = trim($input['project_name'] ?? '');
    $projectDescription = trim($input['project_description'] ?? NULL); // Descripción puede ser NULL

    if (empty($projectName)) { sendJsonResponse(400, ['error' => 'El nombre del proyecto es requerido.']); }
    if (strlen($projectName) > 100) { sendJsonResponse(400, ['error' => 'El nombre del proyecto es muy largo (máx 100 caracteres).']); }

    $slug = strtolower(trim(preg_replace('/[^A-Za-z0-9-]+/', '-', $projectName), '-'));
    if (empty($slug)) { $slug = 'proyecto-' . time(); }

    // TODO: Verificar si user_id + slug ya existe para evitar duplicados por usuario.

    $conn = new mysqli($dbHost, $dbUser, $dbPass, $dbName, (int)$dbPort);
    if ($conn->connect_error) { /* ... manejo error ... */ sendJsonResponse(500, ['error' => 'Error DB Connect (POST)']);}

    $stmt_create = $conn->prepare("INSERT INTO projects (user_id, name, slug, description, created_at, updated_at) VALUES (?, ?, ?, ?, NOW(), NOW())");
    if ($stmt_create === false) { /* ... manejo error ... */ sendJsonResponse(500, ['error' => 'Error DB Prepare (POST)']);}
    $stmt_create->bind_param("isss", $currentUserId, $projectName, $slug, $projectDescription);

    if ($stmt_create->execute()) {
        $newProjectId = $conn->insert_id;
        $stmt_create->close();
        $conn->close();
        sendJsonResponse(201, [
            'success' => true,
            'message' => 'Proyecto creado exitosamente.',
            'project_id' => $newProjectId,
            'project_slug' => $slug
        ]);
    } else {
        $error_msg = $stmt_create->error;
        $stmt_create->close();
        $conn->close();
        error_log("Error DB Execute (create project): " . $error_msg);
        sendJsonResponse(500, ['error' => 'Error al crear el proyecto.', 'details' => $error_msg]);
    }

} else {
    sendJsonResponse(405, ['error' => 'Método no permitido.']);
}
?>