document.addEventListener('DOMContentLoaded', () => {
    const stepConnect = document.getElementById('step-connect-source');
    const stepRepo = document.getElementById('step-select-repo');
    const stepConfig = document.getElementById('step-configure-app');

    const sourceButtons = document.querySelectorAll('.source-button');
    const repoListContainer = document.getElementById('repo-list-container'); // Asumimos que aquí añadiremos la lista
    const selectRepoButtons = document.querySelectorAll('.select-repo-button'); // Si los ponemos estáticos para probar
    const disconnectButton = document.getElementById('disconnect-account');
    const connectedAccountName = document.getElementById('connected-account-name');

    const createAppForm = document.getElementById('create-app-form');
    const appNameInput = document.getElementById('app-name');
    const appUrlPreview = document.getElementById('app-url-preview');
    const selectedRepoNameDisplay = document.getElementById('selected-repo-name');

    // --- Simulación Flujo ---

    // 1. Al hacer clic en "Conectar con GitHub" (Simulado)
    sourceButtons.forEach(button => {
        if (!button.disabled && button.dataset.provider === 'github') { // Solo el de GitHub por ahora
            button.addEventListener('click', () => {
                console.log('Simulando conexión con GitHub...');
                // Aquí iría la redirección OAuth real
                // Para simular, mostramos el siguiente paso después de un delay
                stepConnect.style.display = 'none';
                stepRepo.style.display = 'block';
                // Simular carga de repos
                loadFakeRepos();
            });
        }
    });

    // 2. Simular carga de repositorios
    function loadFakeRepos() {
        repoListContainer.innerHTML = '<p>Cargando...</p>'; // Mostrar carga
        setTimeout(() => {
            const fakeRepos = [
                { name: 'mi-blog-personal', isPrivate: false },
                { name: 'proyecto-node-api', isPrivate: true },
                { name: 'landing-page-cliente', isPrivate: false },
                { name: 'configuracion-servidor', isPrivate: true },
                { name: 'experimento-react', isPrivate: false }
            ];
            repoListContainer.innerHTML = ''; // Limpiar carga
            if (fakeRepos.length === 0) {
                repoListContainer.innerHTML = '<p>No se encontraron repositorios.</p>';
            } else {
                fakeRepos.forEach(repo => {
                    const repoItem = document.createElement('div');
                    repoItem.classList.add('repo-item');
                    repoItem.innerHTML = `
                        <span><i class="fas ${repo.isPrivate ? 'fa-lock' : 'fa-book'}"></i> ${repo.name}</span>
                        <button class="btn btn-sm btn-primary select-repo-button" data-repo-name="${repo.name}">Seleccionar</button>
                    `;
                    repoListContainer.appendChild(repoItem);
                });
            }
        }, 1500); // Simular delay de API
    }

    // 3. Al seleccionar un repositorio (Usando event delegation)
    repoListContainer.addEventListener('click', (event) => {
        if (event.target.classList.contains('select-repo-button')) {
            const repoName = event.target.dataset.repoName;
            console.log(`Repositorio seleccionado: ${repoName}`);

            // Mostrar paso de configuración
            stepConfig.style.display = 'block';
            selectedRepoNameDisplay.textContent = repoName;

            // Sugerir nombre de app y actualizar preview
            const suggestedAppName = repoName.toLowerCase().replace(/[^a-z0-9-]/g, '-').substring(0, 24); // Limpieza básica
            appNameInput.value = suggestedAppName;
            updateAppUrlPreview(suggestedAppName);

            // Opcional: scroll hacia la sección de configuración
            stepConfig.scrollIntoView({ behavior: 'smooth' });
        }
    });

    // 4. Actualizar previsualización de URL mientras se escribe
    if (appNameInput && appUrlPreview) {
        appNameInput.addEventListener('input', (event) => {
            updateAppUrlPreview(event.target.value);
        });
    }

    function updateAppUrlPreview(appName) {
        const sanitizedName = appName.toLowerCase().replace(/[^a-z0-9-]/g, '-');
        appUrlPreview.textContent = `https://${sanitizedName || 'tu-app'}.venecloud.com`;
    }

    // 5. Simular "Desconectar Cuenta"
    if (disconnectButton) {
        disconnectButton.addEventListener('click', () => {
            console.log('Simulando desconexión...');
            stepRepo.style.display = 'none';
            stepConfig.style.display = 'none';
            stepConnect.style.display = 'block';
            // Aquí iría la lógica real para limpiar tokens/sesión
        });
    }

    // 6. Manejar envío del formulario final (Simulado)
    if (createAppForm) {
        createAppForm.addEventListener('submit', (event) => {
            event.preventDefault();
            const formData = new FormData(createAppForm);
            const appName = formData.get('app_name');
            const branch = formData.get('branch');
            const region = formData.get('region');
            const repo = selectedRepoNameDisplay.textContent; // Ya lo teníamos

            console.log('Enviando datos para crear app (simulación):', {
                repo, branch, appName, region // Añadir más campos si es necesario
            });

            // Simulación: Mostrar mensaje y redirigir (después de un delay)
            alert(`Creando aplicación "${appName}" desde ${repo} (${branch})... Serás redirigido.`);

            // Redirección simulada a la página de detalles (ajusta la URL)
            setTimeout(() => {
                // En una app real, la URL vendría del backend
                window.location.href = `/apps/${appName}`; // O a app-details.html si es estático
            }, 1000);
        });
    }

}); // Fin DOMContentLoaded