// create-database-script.js
document.addEventListener('DOMContentLoaded', () => {
    // --- Declaración de Elementos del DOM (UNA SOLA VEZ) ---
    const createDbForm = document.getElementById('create-db-form');
    const stepSqlScript = document.getElementById('step-sql-script');
    const stepDbConfig = document.getElementById('step-db-config');
    const stepDbCredentials = document.getElementById('step-db-credentials');

    const dbNameInput = document.getElementById('db-name');
    const dbNamePreview = document.getElementById('db-name-preview');

    const sqlFileUpload = document.getElementById('sql-file-upload');
    const sqlScriptPaste = document.getElementById('sql-script-paste');

    const copyButtons = document.querySelectorAll('.btn-copy'); // Para botón copiar

    // URL de tu API PHP
    // CORRECCIÓN AQUÍ: Añadir /dashboard_app/ si tu dashboard se sirve desde esa subcarpeta en localhost
    const API_ENDPOINT_URL = '/dashboard_app/api/v1/databases.php';
    // Si tuvieras un VirtualHost para dashboard.venecloud.com apuntando a la raíz de dashboard_app, entonces sería:
    // const API_ENDPOINT_URL = '/api/v1/databases.php';
    // Y si usas .htaccess en api/v1/ para quitar .php:
    // const API_ENDPOINT_URL = '/dashboard_app/api/v1/databases'; // O '/api/v1/databases' con vhost

    // --- 1. Actualizar Preview Nombre DB ---
    if (dbNameInput && dbNamePreview) {
        dbNameInput.addEventListener('input', () => {
            dbNamePreview.textContent = dbNameInput.value.trim().toLowerCase().replace(/[^a-z0-9_]/g, '') || 'nombre_db';
        });
        // Inicializar preview al cargar la página
        dbNamePreview.textContent = dbNameInput.value.trim().toLowerCase().replace(/[^a-z0-9_]/g, '') || 'nombre_db';
    }

    // --- 2. Manejar envío del formulario (Llamada a la API) ---
    if (createDbForm) {
        createDbForm.addEventListener('submit', async (event) => { // Marcado como async
            event.preventDefault();

            const sqlFile = sqlFileUpload.files.length > 0 ? sqlFileUpload.files[0] : null;
            let sqlScriptContent = sqlScriptPaste.value.trim();
            const dbName = dbNameInput.value.trim();

            // Validación de nombre de DB
            if (!dbName) {
                alert("Por favor, ingresa un nombre para tu base de datos.");
                dbNameInput.focus();
                return;
            }
            if (!dbName.match(/^[a-z0-9_]+$/i)) {
                 alert("Nombre de base de datos inválido. Solo letras (a-z), números (0-9) y guiones bajos (_).");
                 dbNameInput.focus();
                 return;
            }


            // Si se subió un archivo, intentar leerlo
            if (sqlFile) {
                try {
                    console.log("Leyendo archivo SQL...");
                    sqlScriptContent = await readFileAsText(sqlFile);
                    console.log("Archivo SQL leído.");
                } catch (error) {
                    console.error("Error al leer el archivo SQL:", error);
                    alert("Error al leer el archivo SQL. Asegúrate de que sea un archivo de texto plano.\nIntenta pegando el script o subiendo un archivo .sql válido.");
                    return;
                }
            }

            // Validar que haya script después de intentar leer archivo
            if (!sqlScriptContent) {
                alert("Por favor, sube un archivo SQL o pega tu script.");
                if (!sqlFile) sqlScriptPaste.focus();
                return;
            }

            const submitButton = createDbForm.querySelector('button[type="submit"]');
            submitButton.disabled = true;
            submitButton.innerHTML = '<i class="fas fa-spinner fa-spin"></i> Creando Base de Datos...';

            try {
                console.log('Enviando a API:', API_ENDPOINT_URL);
                console.log('Payload:', JSON.stringify({ dbName: dbName, sqlScript: sqlScriptContent }));

                const response = await fetch(API_ENDPOINT_URL, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({
                        dbName: dbName,
                        sqlScript: sqlScriptContent
                    }),
                });

                const result = await response.json();

                if (!response.ok) {
                    throw new Error(result.error || `Error del servidor: ${response.status} - ${response.statusText}`);
                }

                if (stepSqlScript) stepSqlScript.style.display = 'none';
                if (stepDbConfig) stepDbConfig.style.display = 'none';
                const formActions = createDbForm.querySelector('.creation-form-actions');
                if (formActions) formActions.style.display = 'none';
                
                if (stepDbCredentials) {
                    stepDbCredentials.style.display = 'block';
                    stepDbCredentials.scrollIntoView({ behavior: 'smooth' });
                }

                if (result.credentials) {
                    document.getElementById('db-host').textContent = result.credentials.host;
                    document.getElementById('db-port').textContent = result.credentials.port;
                    document.getElementById('db-user').textContent = result.credentials.user;
                    document.getElementById('db-password').textContent = result.credentials.password;
                    document.getElementById('db-name-final').textContent = result.credentials.database;
                } else {
                    console.error("La respuesta de la API no incluyó 'credentials'.", result);
                    alert("Base de datos creada, pero hubo un problema al obtener las credenciales.");
                }

            } catch (error) {
                console.error('Error al crear la base de datos (fetch o parseo):', error);
                alert(`Error: ${error.message}`);
                submitButton.disabled = false;
                submitButton.innerHTML = '<i class="fas fa-database"></i> Crear y Ejecutar Base de Datos';
            }
        });
    }

    // --- 3. Lógica Botón Copiar Contraseña ---
    copyButtons.forEach(button => {
        button.addEventListener('click', () => {
            const targetId = button.dataset.copytarget;
            const targetElement = document.getElementById(targetId);
            if (targetElement) {
                navigator.clipboard.writeText(targetElement.textContent)
                    .then(() => {
                        const originalIcon = button.innerHTML;
                        button.innerHTML = '<i class="fas fa-check"></i>';
                        setTimeout(() => { button.innerHTML = originalIcon; }, 1500);
                    })
                    .catch(err => {
                        console.error('Error al copiar: ', err);
                        alert('No se pudo copiar la contraseña.');
                    });
            }
        });
    });

    // --- Helper para leer archivo como texto ---
    function readFileAsText(file) {
        return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.onload = event => resolve(event.target.result);
            reader.onerror = error => reject(error);
            reader.readAsText(file);
        });
    }

}); // Fin DOMContentLoaded