<?php require_once 'api/v1/auth/auth_check.php'; ?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Crear Base de Datos MySQL - VeneCloud</title>
    <link rel="stylesheet" href="dashboard.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
</head>
<body>
    <div class="dashboard-layout">
        <!-- Sidebar -->
        <aside class="sidebar" id="sidebar">
            <div class="sidebar-logo"><a href="./">VeneCloud</a></div>
            <nav class="sidebar-nav">
                <ul>
                    <li class="active"><a href="/dashboard_app"><i class="fas fa-cubes fa-fw"></i> <span>Aplicaciones</span></a></li>
                    <li><a href="billing.php"><i class="fas fa-credit-card fa-fw"></i> <span>Facturación</span></a></li>
                    <li><a href="account.php"><i class="fas fa-user-cog fa-fw"></i> <span>Cuenta</span></a></li>
                    <li><a href="docs.php" target="_blank"><i class="fas fa-book fa-fw"></i> <span>Documentación</span></a></li>
                    <li><a href="api/v1/auth/logout.php"><i class="fas fa-sign-out-alt fa-fw"></i> <span>Salir</span></a></li>
                </ul>
            </nav>
        </aside>

        <div class="main-wrapper" id="main-wrapper">
            <!-- Header -->
            <header class="dashboard-header">
                <div class="header-left">
                    <button id="sidebar-toggle" class="btn btn-icon" aria-label="Toggle sidebar"><i class="fas fa-bars"></i></button>
                    <nav aria-label="breadcrumb" class="breadcrumbs">
                         <ol>
                             <li><a href="/dashboard_app/">Aplicaciones</a></li>
                             <li><span aria-current="page">Crear Base de Datos</span></li>
                         </ol>
                    </nav>
                </div>
                <div class="header-right">
                    <div class="user-menu">
                         <span class="user-name"><?php echo htmlspecialchars($_SESSION['user_email'] ?? 'Usuario'); ?></span>
                         <button class="user-menu-toggle"><i class="fas fa-user-circle fa-lg"></i> <i class="fas fa-caret-down"></i></button>
                         <div class="user-menu-dropdown" style="display: none;">
                             <a href="account.php">Mi Cuenta</a>
                             <a href="api/v1/auth/logout.php">Cerrar Sesión</a>
                         </div>
                    </div>
                </div>
            </header>

            <!-- Main Content -->
            <main class="main-content">
                <div class="content-header">
                    <h1>Crear Nueva Base de Datos MySQL</h1>
                </div>

                <form id="create-db-form">
                    <!-- === Paso 1: Script SQL === -->
                    <section class="creation-step" id="step-sql-script">
                        <h2>1. Carga o Pega tu Script SQL</h2>
                        <p>Este script se ejecutará para crear tus tablas y datos iniciales.</p>

                        <div class="form-group">
                            <label for="sql-file-upload">Subir archivo .sql:</label>
                            <input type="file" id="sql-file-upload" name="sql_file" accept=".sql">
                        </div>

                        <div class="form-group">
                            <label for="sql-script-paste">O pega tu script aquí:</label>
                            <textarea id="sql-script-paste" name="sql_script" rows="10" placeholder="CREATE TABLE usuarios (id INT AUTO_INCREMENT PRIMARY KEY, ...);"></textarea>
                        </div>
                        <small class="form-text">Asegúrate de que el script sea compatible con MySQL y no incluya `CREATE DATABASE` (la crearemos por ti).</small>
                    </section>
                    
                    <!-- === Paso 2: Configuración DB === -->
                    <section class="creation-step" id="step-db-config">
                        <h2>2. Nombra tu Base de Datos</h2>
                        <div class="form-group">
                            <label for="db-name">Nombre de la Base de Datos:</label>
                            <input type="text" id="db-name" name="db_name" placeholder="ej: mi_tienda_db" required pattern="[a-z0-9_]+" title="Solo minúsculas, números y guiones bajos (_)">
                             <!-- Modificado el preview del nombre para ser más claro -->
                            <small class="form-text">Nombre final será: <code>vcld_user_<span id="db-name-preview-suffix">nombre_db</span></code></small>
                        </div>
                        <div class="plan-info-notice">
                            <i class="fas fa-info-circle"></i>
                            Tu plan gratuito incluye: 1 base de datos, hasta 100MB de almacenamiento, 5 conexiones simultáneas.
                        </div>
                    </section>

                    <!-- Botón de Acción Principal -->
                    <div class="form-actions creation-form-actions">
                        <button type="submit" class="btn btn-primary btn-lg">
                            <i class="fas fa-database"></i> Crear y Ejecutar Base de Datos
                        </button>
                    </div>
                </form>

                <!-- === Paso 3: Resultado y Credenciales (Oculto inicialmente) === -->
                <section class="creation-step" id="step-db-credentials" style="display: none;">
                    <h2><i class="fas fa-check-circle text-success"></i> ¡Base de Datos Creada!</h2>
                    <p>Tu base de datos MySQL ha sido creada y el script se ha ejecutado.</p>
                    
                    <h3>3. Tus Credenciales de Conexión</h3>
                    <div class="credentials-display">
                        <div class="credential-item">
                            <label>Host:</label>
                            <span id="db-host">mysql.venecloud.com</span> <!-- Placeholder -->
                        </div>
                        <div class="credential-item">
                            <label>Puerto:</label>
                            <span id="db-port">3306</span>
                        </div>
                        <div class="credential-item">
                            <label>Nombre de Usuario:</label>
                            <span id="db-user">tu_usuario_dbuser_ejemplo</span> <!-- Placeholder -->
                        </div>
                        <div class="credential-item">
                            <label>Contraseña:</label>
                            <div class="password-field">
                                <span id="db-password">CONTRASEÑA_SEGURA_AQUI</span> <!-- Placeholder -->
                                <button type="button" class="btn btn-sm btn-icon btn-copy" data-copytarget="db-password" title="Copiar contraseña"><i class="fas fa-copy"></i></button>
                            </div>
                        </div>
                        <div class="credential-item">
                            <label>Nombre Base de Datos:</label>
                            <span id="db-name-final">tu_usuario_mitiendadb_ejemplo</span> <!-- Placeholder -->
                        </div>
                    </div>
                    <div class="important-notice">
                        <i class="fas fa-exclamation-triangle"></i>
                        <strong>Importante:</strong> Copia tu contraseña ahora. Por razones de seguridad, no podrás volver a verla.
                    </div>
                    <div class="form-actions">
                        <a href="/dashboard_app/" class="btn btn-secondary"><i class="fas fa-arrow-left"></i> Volver al Dashboard</a>
                    </div>
                </section>

            </main>
        </div>
    </div>
    <script src="dashboard-script.js"></script>
    <!-- Script específico para esta página (o añadir a dashboard-script.js) -->
    <script src="create-database-script.js"></script>
</body>
</html>