<?php
// create-project.php
require_once 'api/v1/auth/auth_check.php'; // Asegúrate que la ruta sea correcta
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Crear Nuevo Proyecto - VeneCloud</title>
    <link rel="stylesheet" href="dashboard.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
</head>
<body>
    <div class="dashboard-layout">
        <!-- ==================== SIDEBAR ==================== -->
        <aside class="sidebar" id="sidebar">
            <div class="sidebar-logo"><a href="/">VeneCloud</a></div>
            <nav class="sidebar-nav">
                 <ul>
                     <li class="has-submenu active"> <!-- Marcar 'Aplicaciones' como activa y 'open' si el flujo es crear proyecto -->
                         <a href="#" class="submenu-toggle">
                             <i class="fas fa-cubes fa-fw"></i> <span>Aplicaciones</span> <i class="fas fa-chevron-down submenu-arrow"></i>
                         </a>
                         <ul class="submenu">
                             <!-- Considerar añadir "Crear Proyecto" aquí o que sea la acción principal -->
                             <li><a href="#"><span>FrontEnd</span></a></li>
                             <li><a href="#"><span>API / GraphQL</span></a></li>
                             <li><a href="/create-database"><span>BackEnd (Bases de Datos)</span></a></li>
                             <li><a href="/"><i class="fas fa-list fa-fw"></i> <span>Ver Todas</span></a></li>
                         </ul>
                     </li>
                     <li><a href="/billing"><i class="fas fa-credit-card fa-fw"></i> <span>Facturación</span></a></li>
                     <li><a href="/account"><i class="fas fa-user-cog fa-fw"></i> <span>Cuenta</span></a></li>
                     <li><a href="/docs"><i class="fas fa-book fa-fw"></i> <span>Documentación</span></a></li>
                     <li><a href="/api/v1/auth/logout.php"><i class="fas fa-sign-out-alt fa-fw"></i> <span>Salir</span></a></li>
                 </ul>
            </nav>
        </aside>

        <!-- ==================== MAIN WRAPPER ==================== -->
        <div class="main-wrapper" id="main-wrapper">
            <!-- ==================== DASHBOARD HEADER ==================== -->
            <header class="dashboard-header">
                 <div class="header-left">
                    <button id="sidebar-toggle" class="btn btn-icon" aria-label="Toggle sidebar"><i class="fas fa-bars"></i></button>
                     <nav aria-label="breadcrumb" class="breadcrumbs">
                         <ol>
                             <li><a href="/">Proyectos</a></li> <!-- O Aplicaciones si esa es la vista raíz -->
                             <li><span aria-current="page">Crear Nuevo Proyecto</span></li>
                         </ol>
                     </nav>
                 </div>
                <div class="header-right">
                     <div class="user-menu">
                        <span class="user-name"><?php echo htmlspecialchars($currentUserEmail ?? 'Usuario'); ?></span>
                        <button class="user-menu-toggle"><i class="fas fa-user-circle fa-lg"></i> <i class="fas fa-caret-down"></i></button>
                        <div class="user-menu-dropdown" style="display: none;">
                            <a href="/account">Mi Cuenta</a>
                            <a href="/api/v1/auth/logout.php">Cerrar Sesión</a>
                        </div>
                    </div>
                </div>
            </header>

            <!-- ==================== MAIN CONTENT AREA ==================== -->
            <main class="main-content">
                <div class="content-header">
                    <h1>Crear Nuevo Proyecto</h1>
                </div>

                <section class="settings-section"> <!-- Reutilizar estilos de .settings-section -->
                    <form id="create-project-form">
                        <div class="form-group">
                            <label for="project-name">Nombre del Proyecto:</label>
                            <input type="text" id="project-name" name="project_name" placeholder="Ej: Mi Tienda Online, API de Clientes" required>
                            <small class="form-text">Este nombre te ayudará a identificar tu proyecto. (ej: MiTiendaOnline)</small>
                        </div>
                        <div class="form-group">
                            <label for="project-description">Descripción (Opcional):</label>
                            <textarea id="project-description" name="project_description" rows="3" placeholder="Describe brevemente tu proyecto..."></textarea>
                        </div>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary btn-lg">
                                <i class="fas fa-plus-circle"></i> Crear Proyecto
                            </button>
                            <a href="/" class="btn btn-secondary">Cancelar</a>
                        </div>
                    </form>
                    <!-- Sección para mostrar mensajes de éxito o error -->
                    <div id="form-message" class="form-feedback" style="display: none; margin-top: 15px;"></div>
                </section>

            </main> <!-- Fin Main Content -->
        </div> <!-- Fin Main Wrapper -->
    </div> <!-- Fin Dashboard Layout -->

    <script src="dashboard-script.js"></script>
    <!-- Script específico para esta página o añadir lógica a dashboard-script.js -->
    <script>
        document.addEventListener('DOMContentLoaded', () => {
            const createProjectForm = document.getElementById('create-project-form');
            const formMessage = document.getElementById('form-message');
            const API_PROJECT_ENDPOINT = 'api/v1/projects.php'; // Endpoint para crear proyectos

            if (createProjectForm) {
                createProjectForm.addEventListener('submit', async (event) => {
                    event.preventDefault();
                    formMessage.style.display = 'none';
                    formMessage.textContent = '';
                    formMessage.className = 'form-feedback'; // Resetear clases

                    const submitButton = createProjectForm.querySelector('button[type="submit"]');
                    const originalButtonText = submitButton.innerHTML;
                    submitButton.disabled = true;
                    submitButton.innerHTML = '<i class="fas fa-spinner fa-spin"></i> Creando...';

                    const formData = new FormData(createProjectForm);
                    // Convertir FormData a un objeto simple para JSON
                    const data = {};
                    formData.forEach((value, key) => data[key] = value);

                    try {
                        const response = await fetch(API_PROJECT_ENDPOINT, {
                            method: 'POST',
                            headers: {
                                'Content-Type': 'application/json',
                                'Accept': 'application/json'
                            },
                            body: JSON.stringify(data)
                        });

                        const result = await response.json();

                        if (response.ok && result.success) {
                            formMessage.textContent = result.message || '¡Proyecto creado exitosamente!';
                            formMessage.classList.add('success');
                            formMessage.style.display = 'block';
                            submitButton.innerHTML = '<i class="fas fa-check"></i> Creado';
                            // Opcional: Redirigir al dashboard o a la vista del nuevo proyecto
                            setTimeout(() => {
                                window.location.href = '/dashboard_app/'; // Redirigir a la lista de apps/proyectos
                            }, 1500);
                        } else {
                            throw new Error(result.error || `Error del servidor: ${response.status}`);
                        }

                    } catch (error) {
                        console.error('Error al crear el proyecto:', error);
                        formMessage.textContent = `Error: ${error.message}`;
                        formMessage.classList.add('error');
                        formMessage.style.display = 'block';
                        submitButton.disabled = false;
                        submitButton.innerHTML = originalButtonText;
                    }
                });
            }
        });
    </script>
</body>
</html>