document.addEventListener('DOMContentLoaded', () => {
    const sidebar = document.getElementById('sidebar');
    const sidebarToggle = document.getElementById('sidebar-toggle');
    const mainWrapper = document.getElementById('main-wrapper');
    const appActionToggles = document.querySelectorAll('.action-menu-toggle');
    const userMenuToggle = document.querySelector('.user-menu-toggle');
    const userMenuDropdown = document.querySelector('.user-menu-dropdown');

    // --- 1. Toggle Sidebar Collapse ---
    if (sidebarToggle && sidebar) {
        // Cargar estado inicial
        const applySidebarState = (collapsed) => {
            if (collapsed) {
                document.body.classList.add('sidebar-collapsed');
                // Asegurarse que no esté el estado móvil abierto si colapsamos en desktop
                document.body.classList.remove('mobile-sidebar-open');
                sidebar.classList.remove('open');
            } else {
                document.body.classList.remove('sidebar-collapsed');
            }
        };

        // Cargar estado inicial desde localStorage SOLO si NO estamos en vista móvil
        if (window.innerWidth > 768) { // Aplica estado colapsado solo en desktop
            const isCollapsedStored = localStorage.getItem('sidebarCollapsed') === 'true';
            applySidebarState(isCollapsedStored);
        } else {
             // En móvil, asegurar que no esté colapsado por defecto
             applySidebarState(false);
             localStorage.removeItem('sidebarCollapsed'); // Limpiar storage en móvil
        }

sidebarToggle.addEventListener('click', () => {
            if (window.innerWidth <= 768) { // --- Lógica Móvil ---
                const isMobileOpen = sidebar.classList.toggle('open'); // Toggle clase 'open' en sidebar
                document.body.classList.toggle('mobile-sidebar-open', isMobileOpen); // Sincronizar clase en body
                // En móvil no usamos 'sidebar-collapsed'
                document.body.classList.remove('sidebar-collapsed');
                localStorage.removeItem('sidebarCollapsed');
            } else { // --- Lógica Desktop ---
                const shouldBeCollapsed = !document.body.classList.contains('sidebar-collapsed');
                applySidebarState(shouldBeCollapsed);
                localStorage.setItem('sidebarCollapsed', shouldBeCollapsed);
                // Asegurar que no queden clases de móvil
                sidebar.classList.remove('open');
                document.body.classList.remove('mobile-sidebar-open');
            }
        });

         // Cerrar sidebar móvil si se hace clic en el overlay (mejorado)
        document.addEventListener('click', function(event) {
             // Verificar si el overlay (body::after) está activo y si el clic fue en el área del overlay
             const style = window.getComputedStyle(document.body, '::after');
             if (style.opacity === '1' && event.target === document.body) {
                  sidebar.classList.remove('open');
                  document.body.classList.remove('mobile-sidebar-open');
             }
        });

        } else {
         console.error("Error: Sidebar o botón de toggle no encontrado.");
        }


    // --- 2. Toggle App Action Dropdowns ---
    appActionToggles.forEach(toggle => {
        toggle.addEventListener('click', (event) => {
            event.stopPropagation();
            const dropdown = toggle.nextElementSibling;
            if (dropdown && dropdown.classList.contains('action-menu-dropdown')) {
                closeAllDropdowns('.action-menu-dropdown', dropdown);
                closeAllDropdowns('.user-menu-dropdown');
                dropdown.style.display = dropdown.style.display === 'block' ? 'none' : 'block';
            }
        });
    });


    // --- 3. Toggle User Menu Dropdown ---
    if (userMenuToggle && userMenuDropdown) {
        userMenuToggle.addEventListener('click', (event) => {
            event.stopPropagation();
            closeAllDropdowns('.action-menu-dropdown');
            userMenuDropdown.style.display = userMenuDropdown.style.display === 'block' ? 'none' : 'block';
        });
    }


    // --- 4. Cerrar TODOS los Dropdowns al hacer clic fuera ---
    document.addEventListener('click', (event) => {
        // Solo cerrar si el clic NO fue en un botón toggle
        if (!event.target.closest('.action-menu-toggle') && !event.target.closest('.user-menu-toggle')) {
             closeAllDropdowns('.action-menu-dropdown');
             closeAllDropdowns('.user-menu-dropdown');
        }
        // Cerrar sidebar móvil si se hace clic fuera del sidebar
        if (sidebar && document.body.classList.contains('mobile-sidebar-open') && !sidebar.contains(event.target) && !event.target.closest('#sidebar-toggle')) {
            sidebar.classList.remove('open');
            document.body.classList.remove('mobile-sidebar-open');
        }
    });


    // --- 5. Lógica de Tabs (NUEVO) ---
    const tabLinks = document.querySelectorAll('.tab-navigation .tab-link');
    const tabPanes = document.querySelectorAll('.tab-content-area .tab-pane');

    tabLinks.forEach(link => {
        link.addEventListener('click', (event) => {
            event.preventDefault(); // Evitar que cambie la URL con el #

            // Obtener el ID del contenido target desde data-target
            const targetId = link.getAttribute('data-target');
            const targetPane = document.getElementById(targetId);

            // Quitar clase 'active' de todos los links y panes
            tabLinks.forEach(l => l.classList.remove('active'));
            tabPanes.forEach(p => p.classList.remove('active')); // Ocultar todos

            // Añadir clase 'active' al link clickeado y al panel correspondiente
            link.classList.add('active');
            if (targetPane) {
                targetPane.classList.add('active'); // Mostrar el panel target
            }
        });
    });


    // --- Helper Function para cerrar dropdowns ---
    function closeAllDropdowns(selector, excludeDropdown = null) {
        document.querySelectorAll(selector).forEach(dropdown => {
            if (dropdown !== excludeDropdown) {
                dropdown.style.display = 'none';
            }
        });
    }


    // --- Lógica para mostrar/ocultar mensaje "sin apps" (Solo aplica a dashboard.html) ---
    if (document.querySelector('.app-list-container')) { // Ejecutar solo si estamos en la lista
        const appCardExists = document.querySelector('.app-list-container .app-card');
        const noAppsMessage = document.querySelector('.no-apps-message');
        if (noAppsMessage) {
            noAppsMessage.style.display = appCardExists ? 'none' : 'block';
        }
    }

    // --- 6. Lógica Interactividad Variables de Entorno (NUEVO) ---
    const envVarList = document.querySelector('.env-vars-list');
    const addEnvVarForm = document.getElementById('add-env-var-form');

    // Solo ejecutar si estamos en la página con la lista de variables
    if (envVarList) {
        envVarList.addEventListener('click', (event) => {
            const targetButton = event.target.closest('button'); // Busca el botón más cercano al clic

            if (!targetButton) return; // Si no se hizo clic en un botón, salir

            const envVarItem = targetButton.closest('.env-var-item');
            if (!envVarItem) return; // No debería pasar si el botón está dentro

            const envValueSpan = envVarItem.querySelector('.env-value');
            const envKeySpan = envVarItem.querySelector('.env-key');
            const revealButtonIcon = envVarItem.querySelector('.btn-reveal i');

            // --- Acción: Mostrar/Ocultar Valor ---
            if (targetButton.classList.contains('btn-reveal')) {
                if (envValueSpan && revealButtonIcon && envValueSpan.dataset.value) {
                    const isHidden = envValueSpan.textContent === '********';
                    if (isHidden) {
                        envValueSpan.textContent = envValueSpan.dataset.value;
                        revealButtonIcon.classList.remove('fa-eye');
                        revealButtonIcon.classList.add('fa-eye-slash');
                        targetButton.title = "Ocultar valor";
                    } else {
                        envValueSpan.textContent = '********';
                        revealButtonIcon.classList.remove('fa-eye-slash');
                        revealButtonIcon.classList.add('fa-eye');
                        targetButton.title = "Mostrar valor";
                    }
                }
            }

            // --- Acción: Editar Valor (Simulado) ---
            else if (targetButton.classList.contains('btn-edit')) {
                const key = envKeySpan ? envKeySpan.textContent : 'desconocida';
                const currentValue = envValueSpan ? (envValueSpan.dataset.value || 'oculto') : 'oculto';
                // Simulación: Podrías reemplazar el span con un input, o abrir un modal
                console.log(`Simulando edición para la variable: ${key}. Valor actual (si se conoce): ${currentValue}`);
                alert(`Simulación: Editar variable "${key}".`);
                // Aquí iría la lógica para mostrar un formulario/modal de edición real
            }

            // --- Acción: Borrar Variable ---
            else if (targetButton.classList.contains('btn-delete')) {
                const key = envKeySpan ? envKeySpan.textContent : 'desconocida';
                // Confirmación
                if (confirm(`¿Estás seguro de que quieres eliminar la variable de entorno "${key}"? Esta acción no se puede deshacer.`)) {
                     console.log(`Simulando borrado de la variable: ${key}`);
                     envVarItem.remove(); // Eliminar el elemento del DOM
                     // Aquí enviarías la petición al backend para borrarla realmente
                     // Podrías añadir una pequeña animación de salida antes de remove()
                }
            }
        });
    }

    // --- Acción: Añadir Nueva Variable (Simulado) ---
    if (addEnvVarForm) {
        addEnvVarForm.addEventListener('submit', (event) => {
            event.preventDefault(); // Evitar envío real del formulario

            const keyInput = document.getElementById('new-env-key');
            const valueInput = document.getElementById('new-env-value');
            const key = keyInput.value.trim();
            const value = valueInput.value.trim();

            if (!key || !value) {
                alert('Por favor, introduce un nombre (KEY) y un valor para la variable.');
                return;
            }

            console.log(`Simulando añadido de variable: ${key}=${value}`);

            // --- Crear el nuevo elemento HTML para la variable (Simulación) ---
            const newVarItem = document.createElement('div');
            newVarItem.classList.add('env-var-item');
            newVarItem.innerHTML = `
                <span class="env-key">${key}</span>
                <span class="env-value" data-value="${value}">********</span>
                <div class="env-actions">
                    <button class="btn btn-icon btn-sm btn-reveal" title="Mostrar valor"><i class="fas fa-eye"></i></button>
                    <button class="btn btn-icon btn-sm btn-edit" title="Editar"><i class="fas fa-pencil-alt"></i></button>
                    <button class="btn btn-icon btn-sm btn-delete danger-action" title="Eliminar"><i class="fas fa-trash-alt"></i></button>
                </div>
            `;
            // --- Fin Creación ---

            // Añadir el nuevo elemento a la lista
            if (envVarList) {
                envVarList.appendChild(newVarItem);
            }

            // Limpiar el formulario
            keyInput.value = '';
            valueInput.value = '';

            // Aquí enviarías la petición al backend para añadirla realmente
            alert(`Variable "${key}" añadida (simulación).`);
        });
    }

    // --- 7. Lógica Simulación Logs (NUEVO) ---
    const logConnectButton = document.getElementById('log-connect-button');
    const logOutputContent = document.getElementById('log-output-content');
    let logIntervalId = null; // Para guardar el ID del intervalo
    let isLogsConnected = false; // Estado inicial

    // Solo ejecutar si estamos en la página con el botón de logs
    if (logConnectButton && logOutputContent) {
        logConnectButton.addEventListener('click', () => {
            if (!isLogsConnected) {
                // --- Conectar ---
                isLogsConnected = true;
                logConnectButton.dataset.status = 'connected';
                logConnectButton.innerHTML = '<i class="fas fa-pause"></i> <span>Pausar</span>'; // Cambiar icono y texto
                logConnectButton.classList.remove('btn-secondary');
                logConnectButton.classList.add('btn-warning'); // Opcional: Cambiar color

                logOutputContent.innerHTML = ''; // Limpiar mensaje inicial
                appendLogLine("Conectando al stream de logs...", "system");

                // Simular recepción de logs cada X segundos
                logIntervalId = setInterval(() => {
                    appendLogLine(generateFakeLog(), "app");
                }, 1500); // Añadir una línea cada 1.5 segundos (ajustar)

            } else {
                // --- Desconectar/Pausar ---
                isLogsConnected = false;
                logConnectButton.dataset.status = 'disconnected';
                logConnectButton.innerHTML = '<i class="fas fa-play"></i> <span>Conectar</span>'; // Volver a original
                logConnectButton.classList.remove('btn-warning');
                logConnectButton.classList.add('btn-secondary');

                if (logIntervalId) {
                    clearInterval(logIntervalId); // Detener el intervalo
                    logIntervalId = null;
                }
                appendLogLine("Desconectado del stream de logs.", "system");
            }
        });
    }

    // Función para añadir una línea de log al output
    function appendLogLine(message, type = "info") {
        if (!logOutputContent) return;

        const logLine = document.createElement('span'); // Usar span o div
        logLine.style.display = 'block'; // Asegurar salto de línea
        // logLine.classList.add('log-line'); // Si defines estilos específicos

        const timestamp = new Date().toLocaleTimeString();
        let formatedMessage = `[${timestamp}] ${message}`;

        // Añadir estilo simple basado en tipo (opcional)
        if (type === "system") {
            logLine.style.color = "#6c757d"; // Gris
        } else if (type === "error") {
            logLine.style.color = "#dc3545"; // Rojo
        } else if (type === "warn") {
            logLine.style.color = "#ffc107"; // Amarillo
        }

        logLine.textContent = formatedMessage;
        logOutputContent.appendChild(logLine);

        // Auto-scroll hacia abajo
        const logContainer = logOutputContent.parentElement; // El <pre>
        logContainer.scrollTop = logContainer.scrollHeight;
    }

    // Función para generar una línea de log falsa
    function generateFakeLog() {
        const messages = [
            "Request received: GET /api/users",
            "Processing user data...",
            "Database query executed successfully.",
            "WARN: Cache miss for user:123",
            "Response sent: 200 OK",
            "Request received: POST /api/orders",
            "Validating order schema...",
            "ERROR: Invalid payment method provided.",
            "Response sent: 400 Bad Request",
            "Background job 'image-resize' started.",
            "Image resized successfully: image_abc.jpg",
            "Background job 'image-resize' finished.",
            "DEBUG: User session data loaded.",
        ];
        const randomType = Math.random() < 0.1 ? "error" : (Math.random() < 0.2 ? "warn" : "info");
        const randomIndex = Math.floor(Math.random() * messages.length);

        // Devolver mensaje directamente para usar en appendLogLine
        // Nota: appendLogLine ya añade timestamp
        return messages[randomIndex];
    }
  
    // --- 9. Lógica Submenu Sidebar ---
    const submenuToggles = document.querySelectorAll('.sidebar-nav .submenu-toggle');

    console.log('Buscando toggles de submenú:', submenuToggles.length); // DEBUG

    submenuToggles.forEach(toggle => {
        toggle.addEventListener('click', (event) => {
            event.preventDefault(); // Prevenir navegación si href="#"
            console.log('Clic en toggle de submenú detectado.'); // DEBUG

            const parentLi = toggle.closest('.has-submenu');
            if (parentLi) {
                console.log('Parent LI encontrado, haciendo toggle de clase open.'); // DEBUG
                parentLi.classList.toggle('open');
            } else {
                console.error('No se encontró el LI padre (.has-submenu)'); // DEBUG
            }
        });

        // Opcional: Marcar como abierto si una página del submenú está activa
        // Este código debe estar DENTRO del forEach para que 'toggle' esté definido.
        const parentLi = toggle.closest('.has-submenu');
        if (parentLi && parentLi.querySelector('.submenu li.active')) {
             console.log('Submenú marcado como abierto por defecto debido a item activo.'); // DEBUG
             parentLi.classList.add('open');
        }
    }); // Fin del forEach para submenuToggles

}); // Fin DOMContentLoaded