document.addEventListener('DOMContentLoaded', () => {
    // --- Elementos Comunes del DOM (Seleccionar una vez) ---
    const sidebar = document.getElementById('sidebar');
    const sidebarToggle = document.getElementById('sidebar-toggle');
    const appActionToggles = document.querySelectorAll('.action-menu-toggle');
    const userMenuToggle = document.querySelector('.user-menu-toggle');
    const userMenuDropdown = document.querySelector('.user-menu-dropdown');
    const tabLinks = document.querySelectorAll('.tab-navigation .tab-link');
    const tabPanes = document.querySelectorAll('.tab-content-area .tab-pane');
    const envVarList = document.querySelector('.env-vars-list');
    const addEnvVarForm = document.getElementById('add-env-var-form');
    const logConnectButton = document.getElementById('log-connect-button');
    const logOutputContent = document.getElementById('log-output-content');
    const submenuToggles = document.querySelectorAll('.sidebar-nav .submenu-toggle');

    // Variables globales para lógica de logs (si aplica)
    let logIntervalId = null;
    let isLogsConnected = false;

    // --- 1. Toggle Sidebar Collapse ---
    if (sidebarToggle && sidebar) {
        const applySidebarState = (collapsed) => {
            if (collapsed) {
                document.body.classList.add('sidebar-collapsed');
                document.body.classList.remove('mobile-sidebar-open');
                sidebar.classList.remove('open');
            } else {
                document.body.classList.remove('sidebar-collapsed');
            }
        };

        if (window.innerWidth > 768) {
            const isCollapsedStored = localStorage.getItem('sidebarCollapsed') === 'true';
            applySidebarState(isCollapsedStored);
        } else {
            applySidebarState(false);
            localStorage.removeItem('sidebarCollapsed');
        }

        sidebarToggle.addEventListener('click', () => {
            if (window.innerWidth <= 768) { // Lógica Móvil
                console.log("Toggle móvil clickeado"); // DEBUG
                const isMobileOpen = sidebar.classList.toggle('open');
                document.body.classList.toggle('mobile-sidebar-open', isMobileOpen);
                document.body.classList.remove('sidebar-collapsed');
                localStorage.removeItem('sidebarCollapsed');
                // En móvil, no queremos el estado 'sidebar-collapsed' del body que es para desktop
                if (document.body.classList.contains('sidebar-collapsed')) {
                    document.body.classList.remove('sidebar-collapsed');
                    localStorage.removeItem('sidebarCollapsed'); // Limpiar storage si estaba colapsado en desktop
                }
            } else { // Lógica Desktop
                const shouldBeCollapsed = !document.body.classList.contains('sidebar-collapsed');
                applySidebarState(shouldBeCollapsed);
                localStorage.setItem('sidebarCollapsed', shouldBeCollapsed);
                sidebar.classList.remove('open');
                document.body.classList.remove('mobile-sidebar-open');
            }
        });
    } else {
        // No mostrar error si estamos en login.php o register.php donde no hay sidebar
        if (!document.body.classList.contains('auth-page')) { // Asume que añades esta clase a body de login/register
             // console.error("Error: Sidebar o botón de toggle no encontrado.");
        }
    }

    // --- Cerrar Sidebar Móvil al hacer clic en el overlay o fuera ---
    document.addEventListener('click', function(event) {
        if (sidebar && document.body.classList.contains('mobile-sidebar-open')) {
            // Clic en overlay (body::after)
            const style = window.getComputedStyle(document.body, '::after');
            if (style.opacity === '1' && event.target === document.body) {
                 sidebar.classList.remove('open');
                 document.body.classList.remove('mobile-sidebar-open');
            }
            // Clic fuera del sidebar Y no en el botón toggle
            else if (!sidebar.contains(event.target) && sidebarToggle && !sidebarToggle.contains(event.target)) {
                sidebar.classList.remove('open');
                document.body.classList.remove('mobile-sidebar-open');
            }
        }
    });


    // --- 2. Toggle App Action Dropdowns ---
    appActionToggles.forEach(toggle => {
        toggle.addEventListener('click', (event) => {
            event.stopPropagation();
            const dropdown = toggle.closest('.action-menu-container')?.querySelector('.action-menu-dropdown');
            if (dropdown) {
                closeAllDropdowns('.action-menu-dropdown', dropdown);
                closeAllDropdowns('.user-menu-dropdown');
                dropdown.style.display = dropdown.style.display === 'block' ? 'none' : 'block';
            }
        });
    });

    // --- 3. Toggle User Menu Dropdown ---
    if (userMenuToggle && userMenuDropdown) {
        userMenuToggle.addEventListener('click', (event) => {
            event.stopPropagation();
            closeAllDropdowns('.action-menu-dropdown');
            userMenuDropdown.style.display = userMenuDropdown.style.display === 'block' ? 'none' : 'block';
        });
    }

    // --- 4. Cerrar TODOS los Dropdowns al hacer clic fuera (excepto si el clic fue en un toggle) ---
    document.addEventListener('click', (event) => {
        if (!event.target.closest('.action-menu-toggle') && !event.target.closest('.user-menu-toggle')) {
             closeAllDropdowns('.action-menu-dropdown');
             closeAllDropdowns('.user-menu-dropdown');
        }
    });

    // --- 5. Lógica de Tabs ---
    tabLinks.forEach(link => {
        link.addEventListener('click', (event) => {
            event.preventDefault();
            const targetId = link.getAttribute('data-target');
            const targetPane = document.getElementById(targetId);

            tabLinks.forEach(l => l.classList.remove('active'));
            tabPanes.forEach(p => p.classList.remove('active'));

            link.classList.add('active');
            if (targetPane) {
                targetPane.classList.add('active');
            }
        });
    });

    // --- Helper Function para cerrar dropdowns ---
    function closeAllDropdowns(selector, excludeDropdown = null) {
        document.querySelectorAll(selector).forEach(dropdown => {
            if (dropdown !== excludeDropdown) {
                dropdown.style.display = 'none';
            }
        });
    }

    // --- Lógica para mostrar/ocultar mensaje "sin apps" (Solo en index.php) ---
    if (document.body.contains(document.querySelector('.app-list-container'))) {
        const appCardExists = document.querySelector('.app-list-container .app-card');
        const noAppsMessage = document.querySelector('.no-apps-message');
        if (noAppsMessage) {
            noAppsMessage.style.display = appCardExists ? 'none' : 'block';
        }
    }

    // --- 6. Lógica Interactividad Variables de Entorno (Solo en app-details.php) ---
    if (envVarList) {
        envVarList.addEventListener('click', (event) => {
            const targetButton = event.target.closest('button');
            if (!targetButton) return;
            const envVarItem = targetButton.closest('.env-var-item');
            if (!envVarItem) return;

            const envValueSpan = envVarItem.querySelector('.env-value');
            const envKeySpan = envVarItem.querySelector('.env-key');
            const revealButtonIcon = envVarItem.querySelector('.btn-reveal i');

            if (targetButton.classList.contains('btn-reveal')) {
                if (envValueSpan && revealButtonIcon && envValueSpan.dataset.value) {
                    const isHidden = envValueSpan.textContent === '********';
                    envValueSpan.textContent = isHidden ? envValueSpan.dataset.value : '********';
                    revealButtonIcon.classList.toggle('fa-eye', !isHidden);
                    revealButtonIcon.classList.toggle('fa-eye-slash', isHidden);
                    targetButton.title = isHidden ? "Ocultar valor" : "Mostrar valor";
                }
            } else if (targetButton.classList.contains('btn-edit')) {
                const key = envKeySpan ? envKeySpan.textContent : 'desconocida';
                alert(`Simulación: Editar variable "${key}".`);
            } else if (targetButton.classList.contains('btn-delete')) {
                const key = envKeySpan ? envKeySpan.textContent : 'desconocida';
                if (confirm(`¿Seguro que quieres eliminar la variable "${key}"?`)) {
                    envVarItem.remove();
                    // TODO: Llamada API para borrar
                }
            }
        });
    }

    if (addEnvVarForm) {
        addEnvVarForm.addEventListener('submit', (event) => {
            event.preventDefault();
            const keyInput = document.getElementById('new-env-key');
            const valueInput = document.getElementById('new-env-value');
            const key = keyInput.value.trim();
            const value = valueInput.value.trim();

            if (!key || !value) { alert('Introduce KEY y Valor.'); return; }

            const newVarItem = document.createElement('div');
            newVarItem.classList.add('env-var-item');
            newVarItem.innerHTML = `
                <span class="env-key">${key}</span>
                <span class="env-value" data-value="${value}">********</span>
                <div class="env-actions">
                    <button class="btn btn-icon btn-sm btn-reveal" title="Mostrar valor"><i class="fas fa-eye"></i></button>
                    <button class="btn btn-icon btn-sm btn-edit" title="Editar"><i class="fas fa-pencil-alt"></i></button>
                    <button class="btn btn-icon btn-sm btn-delete danger-action" title="Eliminar"><i class="fas fa-trash-alt"></i></button>
                </div>`;
            if (envVarList) envVarList.appendChild(newVarItem);
            keyInput.value = ''; valueInput.value = '';
            alert(`Variable "${key}" añadida (simulación).`);
            // TODO: Llamada API para añadir
        });
    }

    // --- 7. Lógica Simulación Logs (Solo en app-details.php) ---
    if (logConnectButton && logOutputContent) {
        logConnectButton.addEventListener('click', () => {
            if (!isLogsConnected) {
                isLogsConnected = true;
                logConnectButton.dataset.status = 'connected';
                logConnectButton.innerHTML = '<i class="fas fa-pause"></i> <span>Pausar</span>';
                logConnectButton.classList.replace('btn-secondary', 'btn-warning');
                logOutputContent.innerHTML = '';
                appendLogLine("Conectando al stream de logs...", "system");
                logIntervalId = setInterval(() => appendLogLine(generateFakeLog(), "app"), 1500);
            } else {
                isLogsConnected = false;
                logConnectButton.dataset.status = 'disconnected';
                logConnectButton.innerHTML = '<i class="fas fa-play"></i> <span>Conectar</span>';
                logConnectButton.classList.replace('btn-warning', 'btn-secondary');
                if (logIntervalId) clearInterval(logIntervalId);
                logIntervalId = null;
                appendLogLine("Desconectado del stream de logs.", "system");
            }
        });
    }

    function appendLogLine(message, type = "info") { // Helper para logs
        if (!logOutputContent) return;
        const logLine = document.createElement('span');
        logLine.style.display = 'block';
        const timestamp = new Date().toLocaleTimeString();
        logLine.textContent = `[${timestamp}] ${message}`;
        if (type === "system") logLine.style.color = "#6c757d";
        else if (type === "error") logLine.style.color = "#dc3545";
        else if (type === "warn") logLine.style.color = "#ffc107";
        logOutputContent.appendChild(logLine);
        const logContainer = logOutputContent.parentElement;
        if (logContainer) logContainer.scrollTop = logContainer.scrollHeight;
    }

    function generateFakeLog() { // Helper para logs
        const messages = ["Request GET /users","Processing...","DB Query OK","WARN: Cache miss","Resp: 200 OK"];
        return messages[Math.floor(Math.random() * messages.length)];
    }
  
    // --- 9. Lógica Submenu Sidebar ---
       // --- 9. Lógica Submenu Sidebar ---
    const submenuToggles = document.querySelectorAll('.sidebar-nav .submenu-toggle'); // Esta línea ya estaba arriba, solo la incluyo por contexto

    if (submenuToggles.length > 0) {
        console.log('Encontrados toggles de submenú:', submenuToggles.length);
        submenuToggles.forEach(toggle => { // <--- APERTURA DEL forEach
            toggle.addEventListener('click', (event) => {
                event.preventDefault();
                const parentLi = toggle.closest('.has-submenu');
                if (parentLi) {
                    parentLi.classList.toggle('open');
                } else {
                    console.error('Submenú: No se encontró el LI padre (.has-submenu) para el toggle:', toggle);
                }
            });

            // Marcar como abierto si una página del submenú está activa al cargar
            const parentLi = toggle.closest('.has-submenu'); // Esto se aplica a cada 'toggle' en el bucle
            if (parentLi && parentLi.querySelector('.submenu li.active')) {
                 parentLi.classList.add('open');
            }
        }); // <--- ¡¡¡ESTA ES LA LLAVE DE CIERRE QUE FALTABA PARA EL forEach!!!
    } else {
        // No es un error si no hay submenús en la página actual (ej: login)
        // console.log('No se encontraron toggles de submenú en esta página.');
    }

}); // Fin DOMContentLoaded