<?php
// login.php (PÁGINA DE INTERFAZ - DENTRO DE DASHBOARD_APP)

// Función para verificar HTTPS
function isSecure() {
    return
        (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off')
        || (!empty($_SERVER['SERVER_PORT']) && $_SERVER['SERVER_PORT'] == 443)
        || (!empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] === 'https')
        || (!empty($_SERVER['HTTP_X_FORWARDED_SSL']) && $_SERVER['HTTP_X_FORWARDED_SSL'] === 'on');
}

// 1. Iniciar sesión para verificar si ya está logueado
if (session_status() == PHP_SESSION_NONE) {
    $cookieParams = session_get_cookie_params();
    session_set_cookie_params([
        'lifetime' => 0,
        'path' => '/',
        // 'domain' => '.venecloud.com', // <--- YA NO ES NECESARIO
        'secure' => isSecure(),
        'httponly' => true,
        'samesite' => 'Lax'
    ]);
    session_start();
}

// 2. Si ya está logueado, redirigir al dashboard principal
if (isset($_SESSION['logged_in']) && $_SESSION['logged_in'] === true) {
    header('Location: /'); // Redirigir a la raíz del dashboard (index.php)
    exit();
}

// 3. Si no está logueado, mostrar el HTML del formulario
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="icon" href="./images/x-icon/favicon.ico" type="image/x-icon">
    <title>Iniciar Sesión - VeneCloud Dashboard</title>
    <link rel="stylesheet" href="dashboard.css"> <!-- Asegúrate que enlace a tu CSS del dashboard -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <!-- Estilos Auth (Puedes moverlos a dashboard.css si prefieres) -->
    <style>
        body { display: flex; justify-content: center; align-items: center; min-height: 100vh; background-color: #f4f7f6; }
        .auth-container { max-width: 420px; width: 90%; padding: 30px 40px; background-color: #fff; border-radius: 8px; box-shadow: 0 4px 15px rgba(0,0,0,0.1); text-align: center; }
        .auth-container h1 { margin-bottom: 25px; color: #333; font-size: 1.8em; }
        .auth-container .btn-google { display: inline-flex; align-items: center; justify-content: center; width: 100%; padding: 12px; margin-bottom: 20px; border: 1px solid #ccc; border-radius: 4px; background-color: #fff; color: #555; font-weight: 500; cursor: pointer; transition: background-color 0.3s; }
        .auth-container .btn-google:hover { background-color: #f8f8f8; }
        .auth-container .btn-google i { color: #DB4437; margin-right: 10px; font-size: 1.2em; }
        .auth-separator { display: flex; align-items: center; text-align: center; color: #aaa; margin: 25px 0; }
        .auth-separator::before, .auth-separator::after { content: ''; flex: 1; border-bottom: 1px solid #eee; }
        .auth-separator:not(:empty)::before { margin-right: .5em; }
        .auth-separator:not(:empty)::after { margin-left: .5em; }
        .form-group { margin-bottom: 20px; text-align: left; }
        .form-group label { display: block; margin-bottom: 5px; font-weight: 500; font-size: 0.9em; color: #555;}
        .form-group input { width: 100%; padding: 10px 12px; border: 1px solid #ccc; border-radius: 4px; font-size: 1em; }
        .auth-container .btn-submit { width: 100%; padding: 12px; background-color: #5a3ab2; color: white; border: none; border-radius: 4px; font-size: 1.1em; font-weight: bold; cursor: pointer; transition: background-color 0.3s; }
        .auth-container .btn-submit:hover { background-color: #4a2a92; }
        .auth-footer { margin-top: 25px; font-size: 0.9em; }
        .auth-footer a { color: #007bff; text-decoration: none; }
        .auth-footer a:hover { text-decoration: underline; }
        .forgot-password { text-align: right; font-size: 0.85em; margin-top: -10px; margin-bottom: 15px; }
        .auth-header { text-align: center; margin-bottom: 30px; }
         .auth-header a { color:#343a40; font-size: 2em; font-weight: bold; text-decoration: none; }
    </style>
</head>
<body>
    <div class="auth-container">
         <div class="auth-header">
             <!-- Enlace a la raíz del dashboard -->
            <a href="/">VeneCloud</a>
         </div>
        <h1>Iniciar Sesión</h1>

        <!-- Opción Google -->
        <button type="button" class="btn-google" id="google-login-button">
            <i class="fab fa-google"></i> Iniciar sesión con Google
        </button>

        <div class="auth-separator">o inicia sesión con tu email</div>

        <!-- Formulario Tradicional -->
         <!-- Action apunta a la API relativa DENTRO del mismo subdominio --
         <form id="login-form" method="POST" action="/dashboard_app/api/v1/auth/login.php">
            <div class="form-group">
                <label for="email">Correo Electrónico</label>
                <input type="email" id="email" name="email" required>
            </div>
            <div class="form-group">
                <label for="password">Contraseña</label>
                <input type="password" id="password" name="password" required>
            </div>
             <div class="forgot-password">
                 <a href="/forgot-password">¿Olvidaste tu contraseña?</a> 
             </div>
            <button type="submit" class="btn-submit">Iniciar Sesión</button>
        </form>
        <!-- Fin Action apunta a la API relativa DENTRO del mismo subdominio -->
        
        <div class="auth-footer">
             <!-- Enlace a la página de registro DENTRO del dashboard -->
            ¿No tienes una cuenta? <a href="https://dashboard.venecloud.com/dashboard_app/register.php">Regístrate</a> <!-- O href="/register" -->
        </div>
    </div>

     <!-- Script para manejar Google Sign-In y login tradicional -->
     <script>
        // --- Google Login ---
        // Dentro del script de login.php y register.php (páginas)
        
        // --- Google Login ---
        const googleLoginBtn = document.getElementById('google-login-button');
        if (googleLoginBtn) {
            googleLoginBtn.addEventListener('click', () => {
                console.log('Iniciando flujo de login con Google...');
                // Redirigir al script PHP que inicia el flujo OAuth
                window.location.href = '/dashboard_app/api/v1/auth/google-start.php'; // <<< APUNTAR AQUÍ
            });
        }
        
        // --- Login Tradicional con Fetch ---
        const loginForm = document.getElementById('login-form');
        const submitButton = loginForm ? loginForm.querySelector('button[type="submit"]') : null;

        if (loginForm && submitButton) {
            loginForm.addEventListener('submit', async (event) => {
                event.preventDefault();
                const originalButtonText = submitButton.innerHTML;
                submitButton.disabled = true;
                submitButton.innerHTML = '<i class="fas fa-spinner fa-spin"></i> Iniciando...';
                const formData = new FormData(loginForm);
                const apiEndpoint = loginForm.action; // Ya es la ruta relativa correcta

                try {
                    const response = await fetch(apiEndpoint, {
                        method: 'POST',
                        body: formData
                    });
                    const result = await response.json();

                    if (response.ok && result.success) {
                        console.log('Login exitoso, redirigiendo al dashboard...');
                        window.location.href = 'https://dashboard.venecloud.com/dashboard_app/'; // Redirigir a la raíz del dashboard
                    } else {
                        throw new Error(result.error || 'Error desconocido.');
                    }
                } catch (error) {
                    console.error('Error en el proceso de login:', error);
                    alert(`Error al iniciar sesión: ${error.message}`);
                    submitButton.disabled = false;
                    submitButton.innerHTML = originalButtonText;
                }
            });
        }
     </script>
</body>
</html>