<?php
require_once 'api/v1/auth/auth_check.php'; // Autenticación

// Obtener el slug del proyecto de la URL
$projectSlug = trim($_GET['slug'] ?? '');

if (empty($projectSlug)) {
    // Redirigir al dashboard si no hay slug, o mostrar un error
    header('Location: /'); // O a una página de error específica
    exit();
}

// El JavaScript se encargará de hacer la llamada API para obtener los datos
// y mostrar el nombre del proyecto en el título, etc.
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="icon" href="images/x-icon/favicon.ico" type="image/x-icon">
    <!-- El título se actualizará con JS -->
    <link rel="icon" href="images/x-icon/favicon.ico" type="image/x-icon"> <!-- Asume que images/ está en dashboard_app/ -->
    <title>Detalles del Proyecto - VeneCloud</title>
    <link rel="stylesheet" href="dashboard.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        /* Estilos adicionales para esta página si son necesarios */
        .resource-section { margin-bottom: 30px; }
        .resource-section h3 {
            font-size: 1.3em; padding: 15px 20px; margin: 0;
            border-bottom: 1px solid #e9ecef; display: flex;
            align-items: center; color: #343a40; background-color: #f8f9fa;
            border-top-left-radius: 6px; border-top-right-radius: 6px;
        }
        .resource-section h3 i { margin-right: 10px; color: #6c757d; }
        .resource-list { list-style: none; padding: 0; margin: 0; }
        .resource-item {
            display: flex; justify-content: space-between; align-items: center;
            padding: 12px 20px; border: 1px solid #e9ecef; border-top:none;
            background-color: #fff;
        }
        .resource-item:last-child { border-bottom-left-radius: 6px; border-bottom-right-radius: 6px; }
        .resource-item:hover { background-color: #fdfdff; }
        .resource-item .name a { font-weight: 500; color: #007bff; text-decoration:none; }
        .resource-item .name a:hover { text-decoration: underline; }
        .resource-item .status { font-size: 0.85em; }
        .resource-item .actions .btn { margin-left: 5px; }
        .no-resources { padding: 20px; text-align: center; color: #6c757d; background-color: #fff; border: 1px solid #e9ecef; border-top:none; border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}
        .project-description-display { background-color: #f8f9fa; padding:15px; border-radius:4px; margin-bottom:20px; font-size:0.95em; color:#495057; }
    </style>
</head>
<body>
    <div class="dashboard-layout">
        <!-- ==================== SIDEBAR ==================== -->
        <aside class="sidebar" id="sidebar">
            <div class="sidebar-logo"><a href="./">VeneCloud</a></div>
            <nav class="sidebar-nav">
                 <ul>
                     <li class="active"><a href="./"><i class="fas fa-cubes fa-fw"></i> <span>Aplicaciones</span></a></li>
                     <li><a href="billing.php"><i class="fas fa-credit-card fa-fw"></i> <span>Facturación</span></a></li>
                     <li><a href="account.php"><i class="fas fa-user-cog fa-fw"></i> <span>Cuenta</span></a></li>
                     <li><a href="docs.php"><i class="fas fa-book fa-fw"></i> <span>Documentación</span></a></li>
                     <li><a href="api/v1/auth/logout.php"><i class="fas fa-sign-out-alt fa-fw"></i> <span>Salir</span></a></li>
                 </ul>
            </nav>
        </aside>
        </aside>

        <div class="main-wrapper" id="main-wrapper">
            <!-- Header (igual) -->
            <header class="dashboard-header">
                <div class="header-left">
                    <button id="sidebar-toggle" class="btn btn-icon" aria-label="Toggle sidebar"><i class="fas fa-bars"></i></button>
                    <nav aria-label="breadcrumb" class="breadcrumbs">
                         <ol>
                             <li><a href="index.php">Proyectos</a></li>
                             <li><span id="breadcrumb-project-name" aria-current="page">Cargando...</span></li>
                         </ol>
                     </nav>
                </div>
                <div class="header-right">
                     <div class="user-menu">
                        <span class="user-name"><?php echo htmlspecialchars($currentUserEmail ?? 'Usuario'); ?></span>
                        <button class="user-menu-toggle">...</button>
                        <div class="user-menu-dropdown" style="display: none;">...</div>
                    </div>
                </div>
            </header>

            <!-- Main Content -->
            <main class="main-content">
                <div class="content-header">
                    <h1 id="project-details-title">Cargando Detalles del Proyecto...</h1>
                    <!-- Podría haber botones de acción para el proyecto aquí (ej: Editar Nombre, Borrar Proyecto) -->
                </div>

                <div id="project-description-container" class="project-description-display" style="display:none;">
                    <p><strong>Descripción:</strong> <span id="project-description-text"></span></p>
                </div>

                <!-- Sección para Aplicaciones FrontEnd -->
                <section class="resource-section" id="frontend-apps-section">
                    <h3><i class="fas fa-desktop fa-fw"></i> FrontEnd</h3>
                    <ul class="resource-list" id="frontend-apps-list">
                        <!-- Los items se cargarán con JS -->
                        <p class="loading-resources">Cargando...</p>
                    </ul><!--
                    <div class="section-actions" style="padding: 15px 20px; background-color:#fff; border:1px solid #e9ecef; border-top:none; border-bottom-left-radius:6px; border-bottom-right-radius:6px;">
                        <a href="#" id="add-frontend-btn" class="btn btn-secondary btn-sm"><i class="fas fa-plus"></i> Añadir FrontEnd</a>
                    </div>-->
                </section>

                <!-- Sección para Aplicaciones API/GraphQL -->
                <section class="resource-section" id="api-apps-section">
                    <h3><i class="fas fa-code-branch fa-fw"></i> Middleware</h3>
                    <ul class="resource-list" id="api-apps-list">
                        <p class="loading-resources">Cargando...</p>
                    </ul><!--
                     <div class="section-actions" style="padding: 15px 20px; background-color:#fff; border:1px solid #e9ecef; border-top:none; border-bottom-left-radius:6px; border-bottom-right-radius:6px;">
                        <a href="#" id="add-api-btn" class="btn btn-secondary btn-sm"><i class="fas fa-plus"></i> Añadir API</a>
                    </div>-->
                </section>

                <!-- Sección para Bases de Datos -->
                <section class="resource-section" id="databases-section">
                    <h3><i class="fas fa-database fa-fw"></i> BackEnd</h3>
                    <ul class="resource-list" id="databases-list">
                        <p class="loading-resources">Cargando...</p>
                    </ul><!--
                     <div class="section-actions" style="padding: 15px 20px; background-color:#fff; border:1px solid #e9ecef; border-top:none; border-bottom-left-radius:6px; border-bottom-right-radius:6px;">
                        <a href="#" id="add-database-btn" class="btn btn-secondary btn-sm"><i class="fas fa-plus"></i> Añadir Base de Datos</a>
                    </div>-->
                </section>

            </main>
        </div>
    </div>

    <script src="dashboard-script.js"></script>
    <script>
        document.addEventListener('DOMContentLoaded', () => {
            const projectDetailsTitle = document.getElementById('project-details-title');
            const breadcrumbProjectName = document.getElementById('breadcrumb-project-name');
            const projectDescriptionContainer = document.getElementById('project-description-container');
            const projectDescriptionText = document.getElementById('project-description-text');

            const frontendAppsList = document.getElementById('frontend-apps-list');
            const apiAppsList = document.getElementById('api-apps-list');
            const databasesList = document.getElementById('databases-list');

            const addFrontendBtn = document.getElementById('add-frontend-btn');
            const addApiBtn = document.getElementById('add-api-btn');
            const addDatabaseBtn = document.getElementById('add-database-btn');


            // Obtener el slug del proyecto de la URL
            const urlParams = new URLSearchParams(window.location.search);
            const projectSlug = urlParams.get('slug');

            if (!projectSlug) {
                projectDetailsTitle.textContent = 'Error: Proyecto no especificado.';
                document.querySelectorAll('.loading-resources').forEach(el => el.textContent = '');
                return;
            }

            const API_PROJECT_DETAILS_ENDPOINT = `/dashboard_app/api/v1/projects.php?slug=${encodeURIComponent(projectSlug)}`;

            async function fetchProjectDetails() {
                try {
                    const response = await fetch(API_PROJECT_DETAILS_ENDPOINT);
                    if (!response.ok) {
                        const errData = await response.json().catch(() => ({error: `Error ${response.status}`}));
                        throw new Error(errData.error || `Error ${response.status} al cargar detalles del proyecto.`);
                    }
                    const result = await response.json();

                    if (result.success && result.project) {
                        const project = result.project;
                        document.title = `Proyecto: ${project.name} - VeneCloud`;
                        projectDetailsTitle.textContent = project.name;
                        breadcrumbProjectName.textContent = project.name;

                        if (project.description) {
                            projectDescriptionText.textContent = project.description;
                            projectDescriptionContainer.style.display = 'block';
                        } else {
                            projectDescriptionContainer.style.display = 'none';
                        }
                        
                        // Actualizar href de botones de "Añadir"
                        if(addFrontendBtn) addFrontendBtn.href = `create-app.php?project_id=${project.id}&type=frontend`;
                        if(addApiBtn) addApiBtn.href = `create-app.php?project_id=${project.id}&type=api`;
                        if(addDatabaseBtn) addDatabaseBtn.href = `create-database.php?project_id=${project.id}`;


                        renderResourceList(frontendAppsList, project.applications_frontend || [], 'frontend');
                        renderResourceList(apiAppsList, project.applications_api || [], 'api');
                        renderResourceList(databasesList, project.databases || [], 'database');

                    } else {
                        throw new Error(result.error || 'Proyecto no encontrado o respuesta inválida.');
                    }
                } catch (error) {
                    console.error('Error al cargar detalles del proyecto:', error);
                    projectDetailsTitle.textContent = 'Error al Cargar Proyecto';
                    if(breadcrumbProjectName) breadcrumbProjectName.textContent = 'Error';
                    document.querySelectorAll('.loading-resources').forEach(el => el.innerHTML = `<li class="no-resources">${error.message}</li>`);
                }
            }

            function renderResourceList(listElement, resources, type) {
                listElement.innerHTML = ''; // Limpiar "Cargando..."
                if (resources.length === 0) {
                    let message = 'No hay recursos de este tipo en el proyecto.';
                    if (type === 'frontend') message = 'No hay aplicaciones FrontEnd en este proyecto.';
                    else if (type === 'api') message = 'No hay APIs en este proyecto.';
                    else if (type === 'database') message = 'No hay bases de datos en este proyecto.';
                    listElement.innerHTML = `<li class="no-resources">${message}</li>`;
                    return;
                }

                resources.forEach(resource => {
                    const li = document.createElement('li');
                    li.classList.add('resource-item');
                    let name = resource.name || resource.db_name_on_server || 'Sin Nombre';
                    let detailUrl = '#'; // Placeholder
                    let statusClass = '';
                    let statusText = resource.status || 'desconocido';

                    if (type === 'frontend' || type === 'api') {
                        detailUrl = `app-details.php?id=${resource.id}`; // O usar un slug de app
                        statusClass = `status-${resource.status}`; // ej: status-running
                    } else if (type === 'database') {
                        detailUrl = `database-details.php?id=${resource.id}`; // O usar un slug de db
                        statusClass = `status-${resource.status}`; // ej: status-active
                    }

                    li.innerHTML = `
                        <div class="name">
                            <a href="${detailUrl}">${name}</a>
                        </div>
                        <div class="info">
                            <span class="status ${statusClass}"><i class="fas fa-circle"></i> ${statusText}</span>
                            <small style="margin-left:10px;">Creado: ${new Date(resource.created_at).toLocaleDateString('es-VE')}</small>
                        </div>
                        <div class="actions">
                            <a href="${detailUrl}" class="btn btn-sm btn-icon" title="Ver Detalles"><i class="fas fa-eye"></i></a>
                            <!-- Más botones de acción (editar, borrar) aquí -->
                        </div>
                    `;
                    listElement.appendChild(li);
                });
            }

            fetchProjectDetails();
        });
    </script>
</body>
</html>