<?php
// register.php (PÁGINA DE INTERFAZ - DENTRO DE DASHBOARD_APP)

// Función para verificar HTTPS
function isSecure() {
    return
        (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off')
        || (!empty($_SERVER['SERVER_PORT']) && $_SERVER['SERVER_PORT'] == 443)
        || (!empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] === 'https')
        || (!empty($_SERVER['HTTP_X_FORWARDED_SSL']) && $_SERVER['HTTP_X_FORWARDED_SSL'] === 'on');
}

// 1. Iniciar sesión para verificar si ya está logueado
if (session_status() == PHP_SESSION_NONE) {
    $cookieParams = session_get_cookie_params();
    session_set_cookie_params([
        'lifetime' => 0,
        'path' => '/',
        // 'domain' => '.venecloud.com', // YA NO ES NECESARIO
        'secure' => isSecure(),
        'httponly' => true,
        'samesite' => 'Lax'
    ]);
    session_start();
}

// 2. Si ya está logueado, redirigir al dashboard
if (isset($_SESSION['logged_in']) && $_SESSION['logged_in'] === true) {
    header('Location: /');
    exit();
}

// 3. Mostrar formulario si no está logueado
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Registrarse - VeneCloud Dashboard</title>
    <link rel="stylesheet" href="dashboard.css">
     <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <!-- Estilos Auth -->
    <style>
        body { display: flex; justify-content: center; align-items: center; min-height: 100vh; background-color: #f4f7f6; }
        .auth-container { max-width: 420px; width: 90%; padding: 30px 40px; background-color: #fff; border-radius: 8px; box-shadow: 0 4px 15px rgba(0,0,0,0.1); text-align: center; }
        /* ... (copiar resto de estilos .auth-container, etc. desde login.php si no usas auth.css) ... */
         .auth-header { text-align: center; margin-bottom: 30px; }
         .auth-header a { color:#343a40; font-size: 2em; font-weight: bold; text-decoration: none; }
          .auth-container .btn-google { display: inline-flex; align-items: center; justify-content: center; width: 100%; padding: 12px; margin-bottom: 20px; border: 1px solid #ccc; border-radius: 4px; background-color: #fff; color: #555; font-weight: 500; cursor: pointer; transition: background-color 0.3s; }
        .auth-container .btn-google:hover { background-color: #f8f8f8; }
        .auth-container .btn-google i { color: #DB4437; margin-right: 10px; font-size: 1.2em; }
        .auth-separator { display: flex; align-items: center; text-align: center; color: #aaa; margin: 25px 0; }
        .auth-separator::before, .auth-separator::after { content: ''; flex: 1; border-bottom: 1px solid #eee; }
        .auth-separator:not(:empty)::before { margin-right: .5em; }
        .auth-separator:not(:empty)::after { margin-left: .5em; }
        .form-group { margin-bottom: 20px; text-align: left; }
        .form-group label { display: block; margin-bottom: 5px; font-weight: 500; font-size: 0.9em; color: #555;}
        .form-group input { width: 100%; padding: 10px 12px; border: 1px solid #ccc; border-radius: 4px; font-size: 1em; }
        .auth-container .btn-submit { width: 100%; padding: 12px; background-color: #5a3ab2; color: white; border: none; border-radius: 4px; font-size: 1.1em; font-weight: bold; cursor: pointer; transition: background-color 0.3s; }
        .auth-container .btn-submit:hover { background-color: #4a2a92; }
        .auth-footer { margin-top: 25px; font-size: 0.9em; }
        .auth-footer a { color: #007bff; text-decoration: none; }
        .auth-footer a:hover { text-decoration: underline; }
    </style>
</head>
<body>
     <div class="auth-container">
         <div class="auth-header">
            <a href="/">VeneCloud</a>
         </div>
        <h1>Crear Cuenta</h1>

        <!-- Opción Google -->
        <button type="button" class="btn-google" id="google-signup-button">
            <i class="fab fa-google"></i> Registrarse con Google
        </button>

        <div class="auth-separator">o regístrate con tu email</div>

        <!-- Formulario Tradicional -->
        <!-- Action apunta a la API relativa --
        <form id="register-form" method="POST" action="/dashboard_app/api/v1/auth/register.php">
            <div class="form-group">
                <label for="name">Nombre Completo</label>
                <input type="text" id="name" name="name" required>
            </div>
            <div class="form-group">
                <label for="email">Correo Electrónico</label>
                <input type="email" id="email" name="email" required>
            </div>
            <div class="form-group">
                <label for="password">Contraseña (mín. 8 caracteres)</label>
                <input type="password" id="password" name="password" required minlength="8">
            </div>
            <div class="form-group">
                <label for="password_confirmation">Confirmar Contraseña</label>
                <input type="password" id="password_confirmation" name="password_confirmation" required>
            </div>
            <button type="submit" class="btn-submit">Registrarse</button>
        </form>
        <!-- Fin Action apunta a la API relativa -->
        <div class="auth-footer">
            <!-- Enlace a la página de login DENTRO del dashboard -->
            ¿Ya tienes una cuenta? <a href="login.php">Inicia sesión</a> <!-- O href="/login" -->
        </div>
    </div>

     <!-- Script para Google y validación básica -->
     <script>
        // --- Google Signup ---
        const googleSignupBtn = document.getElementById('google-signup-button');
        if (googleSignupBtn) {
            googleSignupBtn.addEventListener('click', () => {
                console.log('Iniciando flujo de registro con Google...');
                 // Redirigir al mismo script PHP que inicia el flujo OAuth
                window.location.href = '/dashboard_app/api/v1/auth/google-start.php'; // <<< APUNTAR AQUÍ
            });
        }

        // --- Validación Contraseña ---
        const form = document.getElementById('register-form');
        const password = document.getElementById('password');
        const passwordConfirm = document.getElementById('password_confirmation');
        if (form && password && passwordConfirm) {
            form.addEventListener('submit', (event) => {
                if (password.value !== passwordConfirm.value) {
                    alert('Las contraseñas no coinciden.');
                    event.preventDefault();
                    passwordConfirm.focus();
                } else {
                    console.log('Enviando formulario de registro...');
                     // El formulario se enviará normalmente porque no usamos fetch aquí
                }
            });
        }
     </script>

</body>
</html>